@@ -38,7 +38,7 @@ K_PLUGIN_FACTORY(SKGAdvicePluginFactory, registerPlugin<SKGAdvicePlugin>();)
  */
 K_EXPORT_PLUGIN(SKGAdvicePluginFactory("skg_advice", "skg_advice"))
 
-SKGAdvicePlugin::SKGAdvicePlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGAdvicePlugin::SKGAdvicePlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
     SKGTRACEIN(10, "SKGAdvicePlugin::SKGAdvicePlugin");
 }
@@ -77,7 +77,7 @@ QString SKGAdvicePlugin::getDashboardWidgetTitle(int iIndex)
     return "";
 }
 
-SKGWidget* SKGAdvicePlugin::getDashboardWidget(int iIndex)
+SKGBoardWidget* SKGAdvicePlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGAdviceBoardWidget(currentDocument);
     else if (iIndex == 1) return new SKGTipOfDayBoardWidget(currentDocument);
