@@ -31,13 +31,13 @@ class SKGMainPanel;
 class SKGDebugPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGDebugPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGDebugPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -89,11 +89,11 @@ public:
     virtual bool isEnabled() const;
 
 private Q_SLOTS:
-    void actionRestartProfiling();
-    void actionOpenProfiling();
+    void onRestartProfiling();
+    void onOpenProfiling();
 
 private:
-    Q_DISABLE_COPY(SKGDebugPlugin);
+    Q_DISABLE_COPY(SKGDebugPlugin)
 
     SKGDocument* m_currentDocument;
 };
