@@ -33,13 +33,13 @@ class SKGMainPanel;
 class SKGDeletePlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGDeletePlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGDeletePlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -72,9 +72,9 @@ public:
     virtual int getOrder() const;
 
 private Q_SLOTS:
-    void actionDelete();
+    void onDelete();
 private:
-    Q_DISABLE_COPY(SKGDeletePlugin);
+    Q_DISABLE_COPY(SKGDeletePlugin)
 
     KAction* m_deleteAction;
 
