@@ -38,7 +38,7 @@ K_PLUGIN_FACTORY(SKGHighlightPluginFactory, registerPlugin<SKGHighlightPlugin>()
  */
 K_EXPORT_PLUGIN(SKGHighlightPluginFactory("skg_highlight", "skg_highlight"))
 
-SKGHighlightPlugin::SKGHighlightPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGHighlightPlugin::SKGHighlightPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
     SKGTRACEIN(10, "SKGHighlightPlugin::SKGHighlightPlugin");
 }
@@ -62,11 +62,9 @@ bool SKGHighlightPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
     //------------
     m_switchHighLight = new KAction(KIcon("bookmarks"), i18nc("Verb", "Switch highlight"), this);
-    connect(m_switchHighLight, SIGNAL(triggered(bool)), this, SLOT(actionSwitchHighLight()));
-    actionCollection()->addAction(QLatin1String("edit_switch_highlight"), m_switchHighLight);
+    connect(m_switchHighLight, SIGNAL(triggered(bool)), this, SLOT(onSwitchHighLight()));
     m_switchHighLight->setShortcut(Qt::CTRL + Qt::Key_H);
-
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_switch_highlight", m_switchHighLight);
+    registerGlobalAction("edit_switch_highlight", m_switchHighLight);
 
 
     //Create yours actions here
@@ -106,10 +104,10 @@ int SKGHighlightPlugin::getOrder() const
     return 6;
 }
 
-void SKGHighlightPlugin::actionSwitchHighLight()
+void SKGHighlightPlugin::onSwitchHighLight()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGHighlightPlugin::actionSwitchHighLight", err);
+    SKGTRACEINRC(10, "SKGHighlightPlugin::onSwitchHighLight", err);
     //Get Selection
     if (SKGMainPanel::getMainPanel() && m_currentDocument) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
@@ -117,7 +115,7 @@ void SKGHighlightPlugin::actionSwitchHighLight()
         {
             SKGBEGINPROGRESSTRANSACTION(*m_currentDocument, i18nc("Noun, name of the user action", "Highlight"), err, nb);
             for (int i = 0; !err && i < nb; ++i) {
-                SKGObjectBase obj = selection.at(i);
+                SKGObjectBase obj(selection.at(i));
                 if (!err) err = obj.setAttribute("t_bookmarked", obj.getAttribute("t_bookmarked") == "Y" ? "N" : "Y");
                 if (!err) err = obj.save();
                 if (!err) err = m_currentDocument->stepForward(i + 1);
