@@ -155,13 +155,8 @@ void SKGMonthlyPluginWidget::onAddTemplate()
         if (!templates.contains(templatFileName)) {
             //Create the new template
             QString source = KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default.txt");
-            if (SKGServices::upload(source, templatFileName)) {
-                //Set error message
-                err.setReturnCode(ERR_FAIL);
-                err.setMessage(i18nc("An error message", "Impossible to copy file from '%1' to '%2'", source, templatFileName));
-            } else {
-                fillTemplateList();
-            }
+            if (SKGServices::upload(source, templatFileName)) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message", "Impossible to copy file from '%1' to '%2'", source, templatFileName));
+            else fillTemplateList();
         }
 
         //Open the created or already existing file
@@ -184,10 +179,7 @@ void SKGMonthlyPluginWidget::onDeleteTemplate()
 
         //Delete the file
         QFile file(templatFileName);
-        if (!file.remove()) {
-            err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Deletion of '%1' failed", templatFileName));
-        }
+        if (!file.remove()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Deletion of '%1' failed", templatFileName));
 
         if (!err) ui.kTemplate->removeItem(ui.kTemplate->findText(templat));
 
