@@ -31,13 +31,13 @@ class SKGMainPanel;
 class SKGSelectAllPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGSelectAllPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGSelectAllPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -88,10 +88,10 @@ public:
     virtual int getOrder() const;
 
 private Q_SLOTS:
-    void actionSelectAll();
+    void onSelectAll();
 
 private:
-    Q_DISABLE_COPY(SKGSelectAllPlugin);
+    Q_DISABLE_COPY(SKGSelectAllPlugin)
 
     SKGDocument* m_currentDocument;
     KAction* m_selectAllAction;
