@@ -72,7 +72,7 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     setXMLFile("../skg_undoredo/skg_undoredo.rc");
 
     //Menu
-    m_undoSaveAction = new KAction(KIcon("document-revert"), i18nc("Verb, action to cancel previous action", "Undo document"), this);
+    m_undoSaveAction = new KAction(KIcon("document-revert"), i18nc("Verb, action to cancel previous action", "Revert document"), this);
     connect(m_undoSaveAction, SIGNAL(triggered(bool)), this, SLOT(onUndoSave()));
     m_undoSaveAction->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_Z);
     registerGlobalAction("edit_undolastsave", m_undoSaveAction);
