@@ -119,15 +119,11 @@ SKGError SKGImportPluginBackend::importFile()
         QProcess p;
         p.setStandardOutputFile(csvfile);
         p.start(cmd);
-        if (!p.waitForFinished() || p.exitCode() != 0) {
-            err.setReturnCode(ERR_FAIL);
-            err.setMessage(i18nc("Error message",  "The following command line failed:\n'%1'", cmd));
-        } else {
+        if (!p.waitForFinished() || p.exitCode() != 0) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed:\n'%1'", cmd));
+        else {
             QFile file(csvfile);
-            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-                err.setReturnCode(ERR_INVALIDARG);
-                err.setMessage(i18nc("Error message",  "Open file '%1' failed", csvfile));
-            } else {
+            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", csvfile));
+            else {
                 QRegExp reggetaccounts(properties["getaccountid"]);
                 QRegExp reggetaccountbalance(properties["getaccountbalance"]);
 
@@ -151,9 +147,7 @@ SKGError SKGImportPluginBackend::importFile()
                         }
                     } else {
                         //This is an error
-                        err.setReturnCode(ERR_FAIL);
-                        err.setMessage(line);
-                        err.addError(ERR_FAIL, i18nc("Error message",  "Impossible to find the account id with the regular expression '%1' in line '%2'", properties["getaccountid"], line));
+                        err.setReturnCode(ERR_FAIL).setMessage(line).addError(ERR_FAIL, i18nc("Error message",  "Impossible to find the account id with the regular expression '%1' in line '%2'", properties["getaccountid"], line));
                         break;
                     }
                 }
@@ -167,10 +161,8 @@ SKGError SKGImportPluginBackend::importFile()
         //Download operations
         if (!err) err = m_importer->getDocument()->stepForward(1, i18nc("Progress message", "Download operations"));
         if (!err) {
-            if (backendAccounts.isEmpty()) {
-                err.setReturnCode(ERR_FAIL);
-                err.setMessage(i18nc("Error message",  "Your backend '%1' seems to be not well configure because no account has been found.", bankendName));
-            } else {
+            if (backendAccounts.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Your backend '%1' seems to be not well configure because no account has been found.", bankendName));
+            else {
                 //Download qif file
                 QDate lastDownload = SKGServices::stringToTime(m_importer->getDocument()->getParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_DATE")).date();
                 QString lastList = m_importer->getDocument()->getParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_LIST");
