@@ -158,10 +158,8 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
         //Automatic build
         //Open file
         QFile file(m_importer->getLocalFileName());
-        if (!file.open(QIODevice::ReadOnly)) {
-            err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-        } else {
+        if (!file.open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+        else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
 
@@ -171,11 +169,8 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
                 stream.readLine();
 
             //Get mapping
-            if (!stream.atEnd()) {
-                m_csvMapping = getCSVMappingFromLine(stream.readLine());
-            } else {
-                err.setReturnCode(ERR_INVALIDARG);
-            }
+            if (!stream.atEnd()) m_csvMapping = getCSVMappingFromLine(stream.readLine());
+            else err.setReturnCode(ERR_INVALIDARG);
 
             //close file
             file.close();
@@ -209,10 +204,8 @@ SKGError SKGImportPluginCsv::setCSVHeaderIndex(int iIndex)
         //Automatic build
         //Open file
         QFile file(m_importer->getLocalFileName());
-        if (!file.open(QIODevice::ReadOnly)) {
-            err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-        } else {
+        if (!file.open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+        else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
 
@@ -277,19 +270,14 @@ SKGError SKGImportPluginCsv::importFile()
         //Open file
         if (!err) {
             QFile file(m_importer->getLocalFileName());
-            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-                err.setReturnCode(ERR_INVALIDARG);
-                err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-            } else {
+            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+            else {
                 QTextStream stream(&file);
                 if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
 
                 //Ignore useless lines
                 int headerIndex = getCSVHeaderIndex();
-                if (headerIndex == -1) {
-                    err.setReturnCode(ERR_FAIL);
-                    err.setMessage(i18nc("Error message",  "Header not found in CSV file"));
-                }
+                if (headerIndex == -1) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Header not found in CSV file"));
 
                 for (int i = 1; i <= headerIndex; ++i)
                     stream.readLine();
@@ -344,12 +332,8 @@ SKGError SKGImportPluginCsv::importFile()
                 //Select dateformat
                 QString dateFormat = m_parameters["date_format"];
                 if (dateFormat.isEmpty()) dateFormat = SKGServices::getDateFormat(dates); //Automatic detection
-                if (!err && dateFormat.isEmpty()) {
-                    err.setReturnCode(ERR_FAIL);
-                    err.setMessage(i18nc("Error message",  "Date format not supported"));
-                }
-                if (!err)
-                    err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat));
+                if (!err && dateFormat.isEmpty())err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
+                if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat));
 
                 //Step 2 done
                 if (!err) err = m_importer->getDocument()->stepForward(2);
@@ -604,8 +588,7 @@ SKGError SKGImportPluginCsv::importFile()
                         }
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
 
                     //Lines treated
                     if (!err) err = m_importer->getDocument()->stepForward(3);
@@ -613,8 +596,7 @@ SKGError SKGImportPluginCsv::importFile()
             }
         }
     }
-    if (!err) err = m_importer->getDocument()->endTransaction(true);
-    else  m_importer->getDocument()->endTransaction(false);
+    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
 
     return err;
 }
@@ -634,10 +616,8 @@ SKGError SKGImportPluginCsv::exportFile()
 
     //Open file
     KSaveFile file(m_importer->getLocalFileName(false));
-    if (!file.open()) {
-        err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
-    } else {
+    if (!file.open())err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
+    else {
         QTextStream out(&file);
         if (!m_importer->getCodec().isEmpty()) out.setCodec(m_importer->getCodec().toAscii().constData());
         err = m_importer->getDocument()->dumpSelectSqliteOrder(
@@ -685,10 +665,8 @@ SKGError SKGImportPluginCsv::importCSVUnit()
             //Open file
             if (!err) {
                 QFile file(m_importer->getLocalFileName());
-                if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-                    err.setReturnCode(ERR_INVALIDARG);
-                    err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-                } else {
+                if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+                else {
                     QTextStream stream(&file);
                     if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
 
@@ -720,12 +698,8 @@ SKGError SKGImportPluginCsv::importCSVUnit()
 
                     //Select dateformat
                     QString dateFormat = SKGServices::getDateFormat(dates);
-                    if (dateFormat.isEmpty()) {
-                        err.setReturnCode(ERR_FAIL);
-                        err.setMessage(i18nc("Error message",  "Date format not supported"));
-                    }
-                    if (!err)
-                        err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat));
+                    if (dateFormat.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
+                    if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat));
 
                     //Step 2 done
                     if (!err) err = m_importer->getDocument()->stepForward(2);
@@ -757,8 +731,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
                             }
                         }
 
-                        if (!err) err = m_importer->getDocument()->endTransaction(true);
-                        else  m_importer->getDocument()->endTransaction(false);
+                        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
 
                         //Lines treated
                         if (!err) err = m_importer->getDocument()->stepForward(3);
@@ -766,8 +739,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
                 }
             }
         }
-        if (!err) err = m_importer->getDocument()->endTransaction(true);
-        else  m_importer->getDocument()->endTransaction(false);
+        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
     }
     return err;
 }
