@@ -79,10 +79,8 @@ SKGError SKGImportPluginGnc::importFile()
 
     //Open file
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
-    if (!file->open(QIODevice::ReadOnly)) {
-        err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-    } else {
+    if (!file->open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+    else {
         QDomDocument doc;
 
         //Set the file without uncompression
@@ -92,12 +90,8 @@ SKGError SKGImportPluginGnc::importFile()
         bool contentOK = doc.setContent(file->readAll(), &errorMsg, &errorLine, &errorCol);
         file->close();
 
-        if (!contentOK) {
-            err.setReturnCode(ERR_ABORT);
-            err.setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
-
-            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
-        } else {
+        if (!contentOK) err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg)).addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
+        else {
             //Get root
             QDomElement docElem = doc.documentElement();
 
@@ -145,8 +139,7 @@ SKGError SKGImportPluginGnc::importFile()
                             if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                         }
 
-                        if (!err) err = m_importer->getDocument()->endTransaction(true);
-                        else  m_importer->getDocument()->endTransaction(false);
+                        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                     }
                     if (!err) err = m_importer->getDocument()->stepForward(1);
 
@@ -231,8 +224,7 @@ SKGError SKGImportPluginGnc::importFile()
                             if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                         }
 
-                        if (!err) err = m_importer->getDocument()->endTransaction(true);
-                        else  m_importer->getDocument()->endTransaction(false);
+                        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                     }
                     if (!err) err = m_importer->getDocument()->stepForward(2);
 
@@ -252,7 +244,7 @@ SKGError SKGImportPluginGnc::importFile()
                             QDomElement operationSlots = operation.firstChildElement("trn:slots");
 
                             SKGOperationObject operationObj;
-                            err = gnucashTemporaryAccount.addOperation(operationObj);
+                            err = gnucashTemporaryAccount.addOperation(operationObj, true);
                             if (!err && !operationDate.isNull()) {
                                 //Format 2007-01-13 00:00:00 +0100
                                 err = operationObj.setDate(QDate::fromString(operationDate.text().left(10), "yyyy-MM-dd"));
@@ -407,7 +399,7 @@ SKGError SKGImportPluginGnc::importFile()
                                     if (parentSet) {
                                         //If the parent is already set, it means that is a transfer
                                         SKGOperationObject operationObj2;
-                                        if (!err) err = act.addOperation(operationObj2);
+                                        if (!err) err = act.addOperation(operationObj2, true);
                                         if (!err) err = operationObj2.setDate(operationObj.getDate());
                                         if (!err) err = operationObj2.setNumber(operationObj.getNumber());
                                         if (!err) err = operationObj2.setMode(operationObj.getMode());
@@ -465,8 +457,7 @@ SKGError SKGImportPluginGnc::importFile()
                             if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                         }
 
-                        if (!err) err = m_importer->getDocument()->endTransaction(true);
-                        else  m_importer->getDocument()->endTransaction(false);
+                        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                     }
                     if (!err) err = m_importer->getDocument()->stepForward(3);
 
@@ -536,8 +527,7 @@ SKGError SKGImportPluginGnc::importFile()
                             if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                         }
 
-                        if (!err) err = m_importer->getDocument()->endTransaction(true);
-                        else  m_importer->getDocument()->endTransaction(false);
+                        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                     }
                     if (!err) err = m_importer->getDocument()->stepForward(4);
 
@@ -572,8 +562,7 @@ SKGError SKGImportPluginGnc::importFile()
                                 if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                             }
 
-                            if (!err) err = m_importer->getDocument()->endTransaction(true);
-                            else  m_importer->getDocument()->endTransaction(false);
+                            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                         }
                     }
                     if (!err) err = m_importer->getDocument()->stepForward(5);
@@ -587,8 +576,7 @@ SKGError SKGImportPluginGnc::importFile()
                     }
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
         }
