@@ -68,10 +68,8 @@ SKGError SKGImportPluginGsb::importFile()
     //Initialisation
     //Open file
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
-    if (!file->open(QIODevice::ReadOnly)) {
-        err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-    } else {
+    if (!file->open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+    else {
         QDomDocument doc;
 
         //Set the file without uncompression
@@ -84,22 +82,18 @@ SKGError SKGImportPluginGsb::importFile()
         //Get root
         QDomElement docElem = doc.documentElement();
 
-        if (!contentOK) {
-            err.setReturnCode(ERR_ABORT);
-            err.setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
-        } else {
+        if (!contentOK) err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
+        else {
             //Check version
             QDomElement general = docElem.firstChildElement("General");
             if (general.isNull()) {
-                err.setReturnCode(ERR_ABORT);
-                err.setMessage(i18nc("Error message",  "Bad version of Grisbi document. Version must be >= 0.6.0"));
+                err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "Bad version of Grisbi document. Version must be >= 0.6.0"));
                 contentOK = false;
             }
         }
 
-        if (!contentOK) {
-            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
-        } else {
+        if (!contentOK) err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
+        else {
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "GSB"), 9);
 
             QMap<QString, SKGUnitObject> mapIdUnit;
@@ -133,8 +127,7 @@ SKGError SKGImportPluginGsb::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(1);
 
@@ -158,8 +151,7 @@ SKGError SKGImportPluginGsb::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(2);
 
@@ -186,18 +178,14 @@ SKGError SKGImportPluginGsb::importFile()
                     if (!err) err = accountObj.setAgencyAddress(getAttribute(account,  "Owner_address"));
                     if (!err) err = accountObj.setClosed(getAttribute(account,  "Closed_account") != "0");
                     if (!err) err = accountObj.save();
-                    if (!err) {
-                        accountObj.setClosed(false); //To be sure that the modification is possible. NOT SAVED
-                        err = accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  "Initial_balance")), mapIdUnit[getAttribute(account,  "Currency")]);
-                    }
+                    if (!err) err = accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  "Initial_balance")), mapIdUnit[getAttribute(account,  "Currency")]);
 
                     mapIdAccount[getAttribute(account,  "Number")] = accountObj;
 
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(3);
 
@@ -216,8 +204,7 @@ SKGError SKGImportPluginGsb::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(4);
 
@@ -234,8 +221,7 @@ SKGError SKGImportPluginGsb::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(5);
 
@@ -258,8 +244,7 @@ SKGError SKGImportPluginGsb::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(6);
 
@@ -285,8 +270,7 @@ SKGError SKGImportPluginGsb::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(7);
 
@@ -304,7 +288,7 @@ SKGError SKGImportPluginGsb::importFile()
                     QString parentOpId = getAttribute(transaction,  "Mo");
                     if (parentOpId == "0") {
                         SKGAccountObject account = mapIdAccount[getAttribute(transaction,  "Ac")];
-                        if (!err) err = account.addOperation(opObj);
+                        if (!err) err = account.addOperation(opObj, true);
                         if (!err) err = opObj.setDate(QDate::fromString(getAttribute(transaction,  "Dt"), "MM/dd/yyyy"));
                         if (!err) err = opObj.setUnit(mapIdUnit[ getAttribute(transaction,  "Cu")]);
                         if (!err) err = opObj.setPayee(mapIdPayee[ getAttribute(transaction,  "Pa")]);
@@ -336,8 +320,7 @@ SKGError SKGImportPluginGsb::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(8);
 
@@ -353,10 +336,7 @@ SKGError SKGImportPluginGsb::importFile()
                     //Creation of the operation
                     SKGAccountObject account = mapIdAccount[getAttribute(transaction,  "Ac")];
                     SKGOperationObject opObj;
-                    bool isClosed = account.isClosed();
-                    if (isClosed) err = account.setClosed(false);
-                    if (!err) err = account.addOperation(opObj);
-                    if (!err && isClosed) err = account.setClosed(true);
+                    if (!err) err = account.addOperation(opObj, true);
                     QDate firstDate = QDate::fromString(getAttribute(transaction,  "Dt"), "MM/dd/yyyy");
                     if (!err) err = opObj.setDate(firstDate);
                     if (!err) err = opObj.setUnit(mapIdUnit[ getAttribute(transaction,  "Cu")]);
@@ -451,13 +431,11 @@ SKGError SKGImportPluginGsb::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(9);
 
-            if (!err) err = m_importer->getDocument()->endTransaction(true);
-            else  m_importer->getDocument()->endTransaction(false);
+            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
 
             if (!err) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
         }
