@@ -60,13 +60,11 @@ SKGError SKGImportPluginJson::exportFile()
 {
     SKGError err;
     QString doc;
-    err = SKGServices::copySqliteDatabaseToJson(m_importer->getDocument()->getDatabase(), doc);
+    err = m_importer->getDocument()->copyToJson(doc);
     if (!err) {
         KSaveFile file(m_importer->getLocalFileName(false));
-        if (!file.open()) {
-            err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
-        } else {
+        if (!file.open())err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
+        else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
             stream << doc << endl;
