@@ -82,10 +82,8 @@ SKGError SKGImportPluginKmy::importFile()
 
     //Open file
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
-    if (!file->open(QIODevice::ReadOnly)) {
-        err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-    } else {
+    if (!file->open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+    else {
         QDomDocument doc;
 
         //Set the file without uncompression
@@ -95,12 +93,8 @@ SKGError SKGImportPluginKmy::importFile()
         bool contentOK = doc.setContent(file->readAll(), &errorMsg, &errorLine, &errorCol);
         file->close();
 
-        if (!contentOK) {
-            err.setReturnCode(ERR_ABORT);
-            err.setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
-
-            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
-        } else {
+        if (!contentOK)err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg)).addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
+        else {
             //Get root
             QDomElement docElem = doc.documentElement();
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "KMY"), 8);
@@ -145,8 +139,7 @@ SKGError SKGImportPluginKmy::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(1);
 
@@ -186,8 +179,7 @@ SKGError SKGImportPluginKmy::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(2);
 
@@ -305,8 +297,7 @@ SKGError SKGImportPluginKmy::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(4);
 
@@ -345,7 +336,7 @@ SKGError SKGImportPluginKmy::importFile()
                     QDomElement operation = transactionList.at(i).toElement();
 
                     SKGOperationObject operationObj;
-                    err = kmymoneyTemporaryAccount.addOperation(operationObj);
+                    err = kmymoneyTemporaryAccount.addOperation(operationObj, true);
                     if (!err) err = operationObj.setDate(QDate::fromString(operation.attribute("postdate"), "yyyy-MM-dd"));
                     if (!err) err = operationObj.setComment(operation.attribute("memo"));
                     if (!err) err = operationObj.setImported(true);
@@ -476,8 +467,7 @@ SKGError SKGImportPluginKmy::importFile()
                             if (parentSet) {
                                 //If the parent is already set, it means that is a transfer
                                 SKGOperationObject operationObj2;
-                                act.setClosed(false); //To be sure that the modification is possible. NOT SAVED
-                                if (!err) err = act.addOperation(operationObj2);
+                                if (!err) err = act.addOperation(operationObj2, true);
                                 if (!err) err = operationObj2.setTemplate(operationObj.isTemplate());
                                 if (!err) err = operationObj2.setDate(operationObj.getDate());
                                 if (!err) err = operationObj2.setNumber(operationObj.getNumber());
@@ -517,8 +507,7 @@ SKGError SKGImportPluginKmy::importFile()
                                 if (!err) err = suboperationObj2.save(true, false);
                             } else {
                                 //We set the parent
-                                act.setClosed(false); //To be sure that the modification is possible. NOT SAVED
-                                if (!err) err = operationObj.setParentAccount(act);
+                                if (!err) err = operationObj.setParentAccount(act, true);
                                 if (!err) err = operationObj.save();
 
                                 //Compute quantity
@@ -545,8 +534,7 @@ SKGError SKGImportPluginKmy::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(6);
 
@@ -609,8 +597,7 @@ SKGError SKGImportPluginKmy::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(7);
 
@@ -621,8 +608,7 @@ SKGError SKGImportPluginKmy::importFile()
             }
             if (!err) err = m_importer->getDocument()->stepForward(8);
 
-            if (!err) err = m_importer->getDocument()->endTransaction(true);
-            else  m_importer->getDocument()->endTransaction(false);
+            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
 
             if (!err) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
         }
@@ -656,10 +642,8 @@ SKGError SKGImportPluginKmy::exportFile()
 
     //Open file
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(false), "application/x-gzip");
-    if (!file->open(QIODevice::WriteOnly)) {
-        err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
-    } else {
+    if (!file->open(QIODevice::WriteOnly))err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
+    else {
         QDomDocument doc("KMYMONEY-FILE");
         QDomComment comment = doc.createComment("Generated by libskgbankmodeler");
         doc.appendChild(comment);
@@ -755,8 +739,7 @@ SKGError SKGImportPluginKmy::exportFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
                 if (!err) err = m_importer->getDocument()->stepForward(2);
 
@@ -796,8 +779,7 @@ SKGError SKGImportPluginKmy::exportFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
                 if (!err) err = m_importer->getDocument()->stepForward(3);
 
@@ -970,8 +952,7 @@ SKGError SKGImportPluginKmy::exportFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
                 if (!err) err = m_importer->getDocument()->stepForward(4);
 
@@ -1029,8 +1010,7 @@ SKGError SKGImportPluginKmy::exportFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
                 if (!err) err = m_importer->getDocument()->stepForward(5);
 
@@ -1049,8 +1029,7 @@ SKGError SKGImportPluginKmy::exportFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
 
                 //<KEYVALUEPAIRS>
@@ -1126,8 +1105,7 @@ SKGError SKGImportPluginKmy::exportFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
                 if (!err) err = m_importer->getDocument()->stepForward(6);
 
@@ -1185,8 +1163,7 @@ SKGError SKGImportPluginKmy::exportFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
                 budgets.setAttribute("count", SKGServices::intToString(nbBudgets));
                 if (!err) err = m_importer->getDocument()->stepForward(7);
@@ -1237,8 +1214,7 @@ SKGError SKGImportPluginKmy::exportFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
 
                 //<CURRENCIES>
@@ -1300,8 +1276,7 @@ SKGError SKGImportPluginKmy::exportFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
 
                 //<REPORTS>
@@ -1314,8 +1289,7 @@ SKGError SKGImportPluginKmy::exportFile()
                 if (!err) err = m_importer->getDocument()->stepForward(8);
             }
 
-            if (!err) err = m_importer->getDocument()->endTransaction(true);
-            else  m_importer->getDocument()->endTransaction(false);
+            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
         }
 
         file->close();
