@@ -106,8 +106,7 @@ SKGError SKGImportPluginMmb::importFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
             }
             if (!err) err = m_importer->getDocument()->stepForward(1);
@@ -151,8 +150,7 @@ SKGError SKGImportPluginMmb::importFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
             }
             if (!err) err = m_importer->getDocument()->stepForward(2);
@@ -177,8 +175,7 @@ SKGError SKGImportPluginMmb::importFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
             }
             if (!err) err = m_importer->getDocument()->stepForward(3);
@@ -204,8 +201,7 @@ SKGError SKGImportPluginMmb::importFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
             }
             if (!err) err = m_importer->getDocument()->stepForward(4);
@@ -230,8 +226,7 @@ SKGError SKGImportPluginMmb::importFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
             }
             if (!err) err = m_importer->getDocument()->stepForward(5);
@@ -256,7 +251,7 @@ SKGError SKGImportPluginMmb::importFile()
                             if (!err)  err = acc.getUnit(unit);
 
                             SKGOperationObject op;
-                            if (!err)  err = acc.addOperation(op);
+                            if (!err)  err = acc.addOperation(op, true);
                             if (!err) {
                                 QString id = attributes.at(3);
                                 if (id != "-1") err = op.setPayee(mapPayee[id]);
@@ -418,8 +413,7 @@ SKGError SKGImportPluginMmb::importFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
             }
             if (!err) err = m_importer->getDocument()->stepForward(6);
@@ -459,7 +453,7 @@ SKGError SKGImportPluginMmb::importFile()
                         if (!err)  err = acc.getUnit(unitCurrency);
 
                         SKGOperationObject op;
-                        if (!err) err = acc.addOperation(op);
+                        if (!err) err = acc.addOperation(op, true);
                         if (!err) err = op.setComment(attributes.at(7));
                         if (!err) err = op.setDate(SKGServices::stringToTime(attributes.at(2)).date());
                         if (!err) err = op.setAttribute("t_imported", "T");
@@ -473,7 +467,7 @@ SKGError SKGImportPluginMmb::importFile()
                         if (!err) err = subop.save(true, false);
 
                         /*SKGOperationObject op2;
-                        if(!err) err = acc.addOperation(op2);
+                        if(!err) err = acc.addOperation(op2, true);
                         if(!err) err = op2.setComment(attributes.at(7));
                         if(!err) err = op2.setDate(SKGServices::stringToTime(attributes.at(2)).date());
                         if(!err) err = op2.setAttribute("t_imported", "T");
@@ -492,8 +486,7 @@ SKGError SKGImportPluginMmb::importFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
             }
             if (!err) err = m_importer->getDocument()->stepForward(7);
@@ -538,7 +531,7 @@ SKGError SKGImportPluginMmb::importFile()
 
                             //Create operation
                             SKGOperationObject op;
-                            if (!err) err = account.addOperation(op);
+                            if (!err) err = account.addOperation(op, true);
                             if (!err) err = op.setComment(attributes.at(5));
                             if (!err) err = op.setDate(SKGServices::stringToTime(attributes.at(1)).date());
                             if (!err) err = op.setAttribute("t_imported", "T");
@@ -554,8 +547,7 @@ SKGError SKGImportPluginMmb::importFile()
                             if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                         }
 
-                        if (!err) err = m_importer->getDocument()->endTransaction(true);
-                        else  m_importer->getDocument()->endTransaction(false);
+                        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                     }
                 }
             }
@@ -618,14 +610,12 @@ SKGError SKGImportPluginMmb::importFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
             }
             if (!err) err = m_importer->getDocument()->stepForward(9);
 
-            if (!err) err = m_importer->getDocument()->endTransaction(true);
-            else  m_importer->getDocument()->endTransaction(false);
+            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
 
             if (!err) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
         }
