@@ -36,7 +36,7 @@
 #include <QUuid>
 #include <qjson/parser.h>
 
-QMap<QString, SKGUnitObject> SKGImportPluginMny::m_mapIdUnit;
+QMap<QString, SKGUnitObject> SKGImportPluginMny::m_mapIdSecurity;
 QMap<QString, SKGAccountObject> SKGImportPluginMny::m_mapIdAccount;
 QMap<QString, SKGCategoryObject> SKGImportPluginMny::m_mapIdCategory;
 QMap<QString, SKGPayeeObject> SKGImportPluginMny::m_mapIdPayee;
@@ -57,6 +57,8 @@ SKGImportPluginMny::SKGImportPluginMny(QObject* iImporter, const QVariantList& i
     Q_UNUSED(iArg);
 
     m_parameters["password"] = "";
+    m_parameters["install_sunriise"] = 'N';
+    m_parameters["find_and_group_transfers"] = 'Y';
 }
 
 SKGImportPluginMny::~SKGImportPluginMny()
@@ -101,34 +103,31 @@ SKGError SKGImportPluginMny::importFile()
 
     //Check install
     if (KStandardDirs::findExe("java").isEmpty()) {
-        err.setReturnCode(ERR_INSTALL);
-        err.setMessage(i18nc("Error message",  "The java application is not installed"));
+        err.setReturnCode(ERR_INSTALL).setMessage(i18nc("Error message",  "The java application is not installed"));
         err.setProperty("application", "java");
         return err;
     }
 
     QString sunriise_jar = QDir::homePath() % "/.skrooge/sunriise.jar";
     if (!QFile(sunriise_jar).exists()) {
-        if (m_parameters.contains("install")) {
+        if (m_parameters["install_sunriise"] == "Y") {
             QDir::home().mkdir(".skrooge");
             err = SKGServices::upload(KUrl("http://skrooge.org/files/sunriise.jar"), KUrl(sunriise_jar));
             if (err) return err;
         } else {
-            err.setReturnCode(ERR_INSTALL);
-            err.setMessage(i18nc("Error message",  "The sunriise application is needed for Microsoft Money import but is not installed in '%1'", sunriise_jar));
+            err.setReturnCode(ERR_INSTALL).setMessage(i18nc("Error message",  "The sunriise application is needed for Microsoft Money import but is not installed in '%1'", sunriise_jar));
             err.setProperty("application", "sunriise");
             return err;
         }
     }
 
     //Initialisation
-    m_mapIdUnit.clear();
+    m_mapIdSecurity.clear();
     m_mapIdAccount.clear();
     m_mapIdCategory.clear();
     m_mapIdPayee.clear();
 
     //Execute sunriise
-
     QString uniqueId = QUuid::createUuid().toString();
     QString temporaryPath = QDir::tempPath() % "/" % uniqueId;
     removeDir(temporaryPath);
@@ -143,7 +142,7 @@ SKGError SKGImportPluginMny::importFile()
     }
     if (p.waitForFinished() && p.exitCode() == 0) {
         //Import
-        err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "MNY"), 4);
+        err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "MNY"), 6);
         //Step 1-Import categories
         if (!err) {
             /*[ {
@@ -160,12 +159,8 @@ SKGError SKGImportPluginMny::importFile()
             QByteArray json = file.readAll();
             file.close();
             QVariantList list = parser.parse(json, &ok).toList();
-            if (!ok || json.isEmpty()) {
-                err.setReturnCode(ERR_FAIL);
-                err.setMessage(parser.errorString());
-
-                err.addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
-            } else {
+            if (!ok || json.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
+            else {
                 SKGTRACEINRC(10, "SKGImportPluginMny::importFile-CATEGORY", err);
                 int nb = list.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
@@ -178,8 +173,9 @@ SKGError SKGImportPluginMny::importFile()
                         QString parentId = category["parentId"].toString();
                         QString id = category["id"].toString();
                         QString name = category["name"].toString();
+                        int level = category["level"].toInt();
 
-                        if (parentId.isEmpty() || m_mapIdCategory.contains(parentId)) {
+                        if (level == t) {
                             SKGCategoryObject catObject(m_importer->getDocument());
                             err = catObject.setName(name);
                             if (!err && !parentId.isEmpty()) err = catObject.setParentCategory(m_mapIdCategory[parentId]);
@@ -193,13 +189,12 @@ SKGError SKGImportPluginMny::importFile()
                     }
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(1);
         }
 
-        //Step -Import payees
+        //Step 2-Import payees
         if (!err) {
             QJson::Parser parser;
             bool ok = false;
@@ -208,12 +203,8 @@ SKGError SKGImportPluginMny::importFile()
             QByteArray json = file.readAll();
             file.close();
             QVariantList list = parser.parse(json, &ok).toList();
-            if (!ok || json.isEmpty()) {
-                err.setReturnCode(ERR_FAIL);
-                err.setMessage(parser.errorString());
-
-                err.addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
-            } else {
+            if (!ok || json.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
+            else {
                 SKGTRACEINRC(10, "SKGImportPluginMny::importFile-PAYEE", err);
                 int nb = list.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
@@ -234,13 +225,52 @@ SKGError SKGImportPluginMny::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(2);
         }
 
-        //Step 3-Import accounts
+        //Step 3-Import securities
+        if (!err) {
+            QJson::Parser parser;
+            bool ok = false;
+            QFile file(temporaryPath % "/securities.json");
+            file.open(QIODevice::ReadOnly);
+            QByteArray json = file.readAll();
+            file.close();
+            QVariantList list = parser.parse(json, &ok).toList();
+            if (!ok || json.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
+            else {
+                SKGTRACEINRC(10, "SKGImportPluginMny::importFile-UNITS", err);
+                int nb = list.count();
+                err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
+                //Create categories
+                for (int i = 0; !err && i < nb; ++i) {
+                    QVariantMap unit = list[i].toMap();
+
+                    QString id = unit["id"].toString();
+                    QString name = unit["name"].toString();
+                    QString symbol = unit["symbol"].toString();
+                    if (symbol.isEmpty()) symbol = name;
+
+                    //Is already created?
+                    SKGUnitObject unitobject(m_importer->getDocument());
+                    err = unitobject.setName(name);
+                    if (!err) err = unitobject.setSymbol(symbol);
+                    if (!err) err = unitobject.setType(SKGUnitObject::SHARE);
+                    //The unit is not saved because it will be saved when used
+
+                    m_mapIdSecurity[id] = unitobject;
+
+                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                }
+
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+            }
+            if (!err) err = m_importer->getDocument()->stepForward(3);
+        }
+
+        //Step 4-Import accounts
         if (!err) {
             /*
             {
@@ -283,12 +313,8 @@ SKGError SKGImportPluginMny::importFile()
                 QByteArray json = file.readAll();
                 file.close();
                 QVariantMap account = parser.parse(json, &ok).toMap();
-                if (!ok || json.isEmpty()) {
-                    err.setReturnCode(ERR_FAIL);
-                    err.setMessage(parser.errorString());
-
-                    err.addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
-                } else {
+                if (!ok || json.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
+                else {
                     //Create currency
                     SKGUnitObject unitObj;
                     SKGUnitObject::createCurrencyUnit(m_importer->getDocument(), account["currencyCode"].toString(), unitObj);
@@ -312,19 +338,17 @@ SKGError SKGImportPluginMny::importFile()
                     if (!err) err = accountObj.setClosed(account["closed"].toBool());
                     if (!err) err = accountObj.save();
 
-                    accountObj.setClosed(false); //Set account open but only in memory. No save
                     m_mapIdAccount[account["id"].toString()] = accountObj;
                 }
 
                 if (!err) err = m_importer->getDocument()->stepForward(i + 1);
             }
 
-            if (!err) err = m_importer->getDocument()->endTransaction(true);
-            else  m_importer->getDocument()->endTransaction(false);
+            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
         }
-        if (!err) err = m_importer->getDocument()->stepForward(3);
+        if (!err) err = m_importer->getDocument()->stepForward(4);
 
-        //Step 4-Import operation
+        //Step 5-Import operation
         if (!err) {
             //List directories
             QStringList list = temporaryDir.entryList(QStringList() << "*.d", QDir::Dirs);
@@ -344,24 +368,29 @@ SKGError SKGImportPluginMny::importFile()
                 QByteArray json = file.readAll();
                 file.close();
                 QVariantList operations = parser.parse(json, &ok).toList();
-                if (!ok || json.isEmpty()) {
-                    err.setReturnCode(ERR_FAIL);
-                    err.setMessage(parser.errorString());
-
-                    err.addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
-                } else {
+                if (!ok || json.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
+                else {
                     int nbo = operations.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nbo);
                     for (int j = 0; !err && j < nbo; ++j) {
                         QVariantMap operation = operations[j].toMap();
                         if (!operation["void"].toBool()) {
                             SKGAccountObject accountObj = m_mapIdAccount[operation["accountId"].toString()];
+                            QString securityId = operation["securityId"].toString();
 
                             SKGUnitObject unitObj;
-                            if (!err) err = accountObj.getUnit(unitObj);
+                            if (securityId.isEmpty()) {
+                                if (!err) err = accountObj.getUnit(unitObj);
+                            } else {
+                                unitObj = m_mapIdSecurity[securityId];
+                                if (!unitObj.getID()) {
+                                    err = unitObj.save();
+                                    m_mapIdSecurity[securityId] = unitObj;
+                                }
+                            }
 
                             SKGOperationObject operationObj;
-                            if (!err) err = accountObj.addOperation(operationObj);
+                            if (!err) err = accountObj.addOperation(operationObj, true);
                             if (!err) err = operationObj.setUnit(unitObj);
                             if (!err) err = operationObj.setDate(QDateTime::fromMSecsSinceEpoch(operation["date"].toULongLong()).date());
                             if (!err) err = operationObj.setComment(operation["memo"].toString());
@@ -433,39 +462,35 @@ SKGError SKGImportPluginMny::importFile()
                         if (!err) err = m_importer->getDocument()->stepForward(j + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                 }
 
                 if (!err) err = m_importer->getDocument()->stepForward(i + 1);
             }
 
-            if (!err) err = m_importer->getDocument()->endTransaction(true);
-            else  m_importer->getDocument()->endTransaction(false);
+            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
         }
 
-        if (!err) err = m_importer->getDocument()->stepForward(4);
+        if (!err) err = m_importer->getDocument()->stepForward(5);
 
-        if (!err) err = m_importer->getDocument()->endTransaction(true);
-        else  m_importer->getDocument()->endTransaction(false);
+        //Step 6-Group operation
+        if (!err && m_parameters["find_and_group_transfers"] == "Y") {
+            int nbg = 0;
+            err = m_importer->findAndGroupTransfers(nbg, true);
+        }
 
+        if (!err) err = m_importer->getDocument()->stepForward(6);
 
+        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
     } else {
-        if (p.exitCode() == 1) {
-            err.setReturnCode(ERR_ENCRYPTION);
-            err.setMessage(i18nc("Error message",  "Invalid password"));
-        } else {
-            err.setReturnCode(ERR_FAIL);
-            err.setMessage(i18nc("Error message",  "The execution of '%1' failed", cmd));
-
-            err.addError(ERR_FAIL, i18nc("Error message",  "The extraction from the Microsoft Money document '%1' failed", m_importer->getFileName().prettyUrl()));
-        }
+        if (p.exitCode() == 1) err.setReturnCode(ERR_ENCRYPTION).setMessage(i18nc("Error message",  "Invalid password"));
+        else err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The execution of '%1' failed", cmd)).addError(ERR_FAIL, i18nc("Error message",  "The extraction from the Microsoft Money document '%1' failed", m_importer->getFileName().prettyUrl()));
     }
 
     removeDir(temporaryPath);
 
     //Clean
-    m_mapIdUnit.clear();
+    m_mapIdSecurity.clear();
     m_mapIdAccount.clear();
     m_mapIdCategory.clear();
     m_mapIdPayee.clear();
