@@ -67,11 +67,7 @@ SKGError SKGImportPluginOfx::importFile()
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginOfx::importFile", err);
 
-    if (!QFile(m_importer->getLocalFileName()).exists()) {
-        err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-    }
-
+    if (!QFile(m_importer->getLocalFileName()).exists()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
     if (!err) err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "OFX"));
     if (!err) {
         SKGImportPluginOfx::m_ofxError = SKGError();
@@ -120,8 +116,7 @@ SKGError SKGImportPluginOfx::importFile()
 
         SKGImportPluginOfx::m_ofxInitialBalance.clear();
 
-        if (!err) err = m_importer->getDocument()->endTransaction(true);
-        else  m_importer->getDocument()->endTransaction(false);
+        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
     }
     return err;
 }
@@ -319,7 +314,7 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
 
         //Create operation
         SKGOperationObject ope;
-        if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = account.addOperation(ope);
+        if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = account.addOperation(ope, true);
         if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.setDate(date);
         if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.setUnit(unit);
         if (!SKGImportPluginOfx::m_ofxError) SKGImportPluginOfx::m_ofxError = ope.setAttribute("t_imported", "T");
