@@ -89,10 +89,8 @@ SKGError SKGImportPluginQif::importFile()
 
         //Open file
         QFile file(m_importer->getLocalFileName());
-        if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-            err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-        } else {
+        if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+        else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
 
@@ -139,12 +137,8 @@ SKGError SKGImportPluginQif::importFile()
             //Select dateformat
             QString dateFormat = m_parameters["date_format"];
             if (dateFormat.isEmpty()) dateFormat = SKGServices::getDateFormat(dates); //Automatic detection
-            if (dateFormat.isEmpty()) {
-                err.setReturnCode(ERR_FAIL);
-                err.setMessage(i18nc("Error message",  "Date format not supported"));
-            }
-            if (!err)
-                err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat));
+            if (dateFormat.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
+            if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat));
 
             //Step 2 done
             if (!err) err = m_importer->getDocument()->stepForward(2);
@@ -195,7 +189,7 @@ SKGError SKGImportPluginQif::importFile()
                         if (account == NULL) {
                             SKGAccountObject defAccount;
                             err = m_importer->getDefaultAccount(defAccount);
-                            if (!err) err = defAccount.addOperation(currentOperation);
+                            if (!err) err = defAccount.addOperation(currentOperation, true);
                             if (!err) account = new SKGAccountObject(defAccount);
                         }
 
@@ -321,12 +315,12 @@ SKGError SKGImportPluginQif::importFile()
                             double initBalance;
                             if (!err) {
                                 if (account != NULL) {
-                                    err = account->addOperation(currentOperation);
+                                    err = account->addOperation(currentOperation, true);
                                     if (!openingbalancecreated) account->getInitialBalance(initBalance, unit);
                                 } else {
                                     SKGAccountObject defAccount;
                                     err = m_importer->getDefaultAccount(defAccount);
-                                    if (!err) err = defAccount.addOperation(currentOperation);
+                                    if (!err) err = defAccount.addOperation(currentOperation, true);
                                     if (!openingbalancecreated) defAccount.getInitialBalance(initBalance, unit);
                                 }
                                 currentOperationInitialized = true;
@@ -380,11 +374,11 @@ SKGError SKGImportPluginQif::importFile()
                             SKGSubOperationObject subcommission;
                             if (!payement.exist()) {
                                 //We have to create a new operation
-                                if (account != NULL) err = account->addOperation(payement);
+                                if (account != NULL) err = account->addOperation(payement, true);
                                 else {
                                     SKGAccountObject defAccount;
                                     err = m_importer->getDefaultAccount(defAccount);
-                                    if (!err) err = defAccount.addOperation(payement);
+                                    if (!err) err = defAccount.addOperation(payement, true);
                                 }
                                 if (!err) err = payement.setDate(currentOperationDate);
                                 if (!err) {
@@ -501,11 +495,11 @@ SKGError SKGImportPluginQif::importFile()
                                 double previousQuantity = currentSubOperation.getQuantity();
                                 if (previousQuantity) {
                                     //We have to create a new operation
-                                    if (account != NULL) err = account->addOperation(payement);
+                                    if (account != NULL) err = account->addOperation(payement, true);
                                     else {
                                         SKGAccountObject defAccount;
                                         err = m_importer->getDefaultAccount(defAccount);
-                                        if (!err) err = defAccount.addOperation(payement);
+                                        if (!err) err = defAccount.addOperation(payement, true);
                                     }
                                     if (!err) err = payement.setDate(currentOperationDate);
                                     if (!err) {
@@ -716,7 +710,7 @@ SKGError SKGImportPluginQif::importFile()
                                             opOrigin.getUnit(unit);
 
                                             SKGOperationObject opTransfer;
-                                            if (!err) err = accountTransfer.addOperation(opTransfer);
+                                            if (!err) err = accountTransfer.addOperation(opTransfer, true);
                                             if (!err) err = opTransfer.setDate(opOrigin.getDate());
                                             if (!err) err = opTransfer.setComment(opOrigin.getComment());
                                             SKGPayeeObject payeeObj;
@@ -766,16 +760,14 @@ SKGError SKGImportPluginQif::importFile()
 
                 delete account;
                 account = NULL;
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
 
                 //Lines treated
                 if (!err) err = m_importer->getDocument()->stepForward(3);
             }
         }
     }
-    if (!err) err = m_importer->getDocument()->endTransaction(true);
-    else  m_importer->getDocument()->endTransaction(false);
+    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
 
     return err;
 }
@@ -796,10 +788,8 @@ SKGError SKGImportPluginQif::exportFile()
 
     //Open file
     KSaveFile file(m_importer->getLocalFileName(false));
-    if (!file.open()) {
-        err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
-    } else {
+    if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
+    else {
         QTextStream stream(&file);
         if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
 
@@ -828,8 +818,7 @@ SKGError SKGImportPluginQif::exportFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(1);
 
@@ -1004,8 +993,7 @@ SKGError SKGImportPluginQif::exportFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(2);
 
@@ -1034,12 +1022,10 @@ SKGError SKGImportPluginQif::exportFile()
                 }
                 stream << "^" << endl;
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(3);
-            if (!err) err = m_importer->getDocument()->endTransaction(true);
-            else  m_importer->getDocument()->endTransaction(false);
+            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
         }
     }
 
