@@ -68,10 +68,8 @@ SKGError SKGImportPluginSkg::importFile()
     SKGError err;
     SKGTRACEINRC(2, "SKGImportPluginSkg::importFile", err);
     QString lfile = m_importer->getLocalFileName();
-    if (lfile.isEmpty()) {
-        err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-    } else {
+    if (lfile.isEmpty()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+    else {
         SKGDocumentBank docOrigin;
         err = docOrigin.load(lfile, m_parameters["password"]);
         if (!err) {
@@ -490,11 +488,7 @@ SKGError SKGImportPluginSkg::exportFile()
     QString file = m_importer->getLocalFileName(false);
     QFile::remove(file);
     if (QFileInfo(file).suffix().toUpper() == "SQLITE") {
-        if (SKGServices::upload(tempFile, file)) {
-            //Set error message
-            err.setReturnCode(ERR_FAIL);
-            err.setMessage(i18nc("An error message", "Creation file '%1' failed", file));
-        }
+        if (SKGServices::upload(tempFile, file)) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message", "Creation file '%1' failed", file));
     } else {
         err = SKGServices::cryptFile(tempFile, file, "", true, m_importer->getDocument()->getDocumentHeader());
         if (!err) {
