@@ -69,10 +69,8 @@ SKGError SKGImportPluginXhb::importFile()
     //Initialisation
     //Open file
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
-    if (!file->open(QIODevice::ReadOnly)) {
-        err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-    } else {
+    if (!file->open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+    else {
         QDomDocument doc;
 
         //Set the file without uncompression
@@ -85,15 +83,9 @@ SKGError SKGImportPluginXhb::importFile()
         //Get root
         QDomElement docElem = doc.documentElement();
 
-        if (!contentOK) {
-            err.setReturnCode(ERR_ABORT);
-            err.setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
-        }
-
-
-        if (!contentOK) {
-            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
-        } else {
+        if (!contentOK) err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
+        if (!contentOK) err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
+        else {
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "XHB"), 4);
 
             QMap<QString, SKGAccountObject> mapIdAccount;
@@ -131,18 +123,14 @@ SKGError SKGImportPluginXhb::importFile()
                         err = accountObj.setClosed(flags == "2" ||  flags == "3");
                     }
                     if (!err) err = accountObj.save();
-                    if (!err) {
-                        accountObj.setClosed(false); //To be sure that the modification is possible. NOT SAVED
-                        err = accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  "initial")), unit);
-                    }
+                    if (!err) err = accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  "initial")), unit);
 
                     mapIdAccount[getAttribute(account,  "key")] = accountObj;
 
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(1);
 
@@ -161,8 +149,7 @@ SKGError SKGImportPluginXhb::importFile()
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(2);
 
@@ -219,8 +206,7 @@ SKGError SKGImportPluginXhb::importFile()
                     }
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(3);
 
@@ -256,7 +242,7 @@ SKGError SKGImportPluginXhb::importFile()
 
                             //Creation of the operation
                             SKGOperationObject opObj;
-                            if (!err) err = account.addOperation(opObj);
+                            if (!err) err = account.addOperation(opObj, true);
                             if (!err) err = opObj.setDate(date);
                             if (!err) err = opObj.setUnit(unit);
                             if (!err) err = opObj.setPayee(payee);
@@ -280,7 +266,7 @@ SKGError SKGImportPluginXhb::importFile()
                             /*if(dst_account != idAccount && dst_account != "0") {
                                 SKGAccountObject account = mapIdAccount[dst_account];
                                 SKGOperationObject op2Obj;
-                                if(!err) err = account.addOperation(op2Obj);
+                                if(!err) err = account.addOperation(op2Obj, true);
                                 if(!err) err = op2Obj.setDate(date);
                                 if(!err) err = op2Obj.setUnit(unit);
                                 if(!err) err = op2Obj.setPayee(payee);
@@ -338,19 +324,15 @@ SKGError SKGImportPluginXhb::importFile()
                         if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
-
+                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
                     if (!err) err = m_importer->getDocument()->stepForward(j);
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true);
-                else  m_importer->getDocument()->endTransaction(false);
+                if (!err) err = m_importer->getDocument()->endTransaction(true); m_importer->getDocument()->endTransaction(false);
             }
             if (!err) err = m_importer->getDocument()->stepForward(4);
 
-            if (!err) err = m_importer->getDocument()->endTransaction(true);
-            else  m_importer->getDocument()->endTransaction(false);
+            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
 
             if (!err) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
         }
