@@ -134,7 +134,7 @@ QString SKGBankPlugin::title() const
 
 QString SKGBankPlugin::icon() const
 {
-    return "view-bank-account";
+    return "view-bank";
 }
 
 QString SKGBankPlugin::toolTip() const
