@@ -109,6 +109,8 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     ui.kAgencyNumberLbl->setText(i18n("%1:", iDocument->getDisplay("t_agency_number")));
     ui.kNumberLbl->setText(i18n("%1:", iDocument->getDisplay("i_number")));
     ui.kAgencyAddressLbl->setText(i18n("%1:", iDocument->getDisplay("t_agency_address")));
+    ui.kMaxLimit->setText(i18n("%1:", iDocument->getDisplay("f_maxamount")));
+    ui.kMinLimit->setText(i18n("%1:", iDocument->getDisplay("f_minamount")));
     ui.kCommentLabel->setText(i18n("%1:", iDocument->getDisplay("t_comment")));
 
     ui.kUnitEdit->setDocument(iDocument);
@@ -270,6 +272,12 @@ void SKGBankPluginWidget::onSelectionChanged()
         ui.kAccountCreatorType->setText(account.getAttribute("t_TYPENLS"));
         ui.kAccountCreatorAddress->setText(account.getAttribute("t_agency_address"));
         ui.kAccountCreatorComment->setText(account.getAttribute("t_comment"));
+        ui.kMinLimitAmout->setText(account.getAttribute("f_minamount"));
+        ui.kMaxLimitAmout->setText(account.getAttribute("f_maxamount"));
+        ui.kMaxLimit->setTristate(false);
+        ui.kMaxLimit->setCheckState(account.isMaxLimitAmountEnabled() ? Qt::Checked : Qt::Unchecked);
+        ui.kMinLimit->setTristate(false);
+        ui.kMinLimit->setCheckState(account.isMinLimitAmountEnabled() ? Qt::Checked : Qt::Unchecked);
 
         double oBalance = 0;
         SKGUnitObject oUnit;
@@ -300,6 +308,12 @@ void SKGBankPluginWidget::onSelectionChanged()
         ui.kAccountCreatorComment->setText(NOUPDATE);
         ui.kAmountEdit->setText(NOUPDATE);
         ui.kUnitEdit->setText(NOUPDATE);
+        ui.kMinLimitAmout->setText(NOUPDATE);
+        ui.kMaxLimitAmout->setText(NOUPDATE);
+        ui.kMaxLimit->setTristate(true);
+        ui.kMaxLimit->setCheckState(Qt::PartiallyChecked);
+        ui.kMinLimit->setTristate(true);
+        ui.kMinLimit->setCheckState(Qt::PartiallyChecked);
     }
 
     //Refresh graph
@@ -458,6 +472,13 @@ void SKGBankPluginWidget::onAddAccountClicked()
             if (!err) err = accountObj.setComment(ui.kAccountCreatorComment->text());
             if (!err) err = accountObj.setNumber(ui.kAccountCreatorNumber->text());
             if (!err) err = accountObj.setType(accountType);
+
+            if (!err) err = accountObj.maxLimitAmountEnabled(ui.kMaxLimit->isChecked());
+            if (!err) err = accountObj.setMaxLimitAmount(ui.kMaxLimitAmout->value());
+
+            if (!err) err = accountObj.minLimitAmountEnabled(ui.kMinLimit->isChecked());
+            if (!err) err = accountObj.setMinLimitAmount(ui.kMinLimitAmout->value());
+
             if (!err) err = accountObj.save(false);
             if (!err) err = setInitialBalanceFromEditor(accountObj);
             if (!err) err = accountObj.save();
@@ -515,6 +536,13 @@ void SKGBankPluginWidget::onModifyAccountClicked()
             if (!err) err = accountObj.setAgencyNumber(ui.kAccountCreatorAgencyNumber->text());
             if (!err) err = accountObj.setAgencyAddress(ui.kAccountCreatorAddress->text());
             if (!err) err = accountObj.setComment(ui.kAccountCreatorComment->text());
+
+            if (!err && ui.kMaxLimit->checkState() != Qt::PartiallyChecked) err = accountObj.maxLimitAmountEnabled(ui.kMaxLimit->isChecked());
+            if (!err && ui.kMaxLimitAmout->text() != NOUPDATE) err = accountObj.setMaxLimitAmount(ui.kMaxLimitAmout->value());
+
+            if (!err && ui.kMinLimit->checkState() != Qt::PartiallyChecked) err = accountObj.minLimitAmountEnabled(ui.kMinLimit->isChecked());
+            if (!err && ui.kMaxLimitAmout->text() != NOUPDATE) err = accountObj.setMinLimitAmount(ui.kMinLimitAmout->value());
+
             if (!err) err = accountObj.save();
 
             //Update bank
