@@ -121,7 +121,7 @@ SKGAdviceList SKGBudgetPlugin::advice(const QStringList& iIgnoredAdvice)
     if (!iIgnoredAdvice.contains("skgbudgetplugin_alarm")) {
         SKGObjectBase::SKGListSKGObjectBase budgets;
         //Query is done on v_budget_display because v_budget_display is faster than v_budget
-        SKGError err = m_currentBankDocument->getObjects("v_budget_display", "(f_CURRENTAMOUNT/f_budgeted_modified>0.8 OR (f_CURRENTAMOUNT<0 AND f_budgeted_modified>0)) AND f_CURRENTAMOUNT!=f_budgeted_modified AND f_budgeted<0 AND (t_PERIOD='" % month % "' OR t_PERIOD='" % year % "');", budgets);
+        SKGError err = m_currentBankDocument->getObjects("v_budget_display", "(f_CURRENTAMOUNT/f_budgeted_modified>0.8 OR (f_CURRENTAMOUNT<0 AND f_budgeted_modified>0)) AND ABS(f_CURRENTAMOUNT-f_budgeted_modified)>" % SKGServices::doubleToString(EPSILON) % " AND f_budgeted<0 AND (t_PERIOD='" % month % "' OR t_PERIOD='" % year % "');", budgets);
         int nb = budgets.count();
         if (nb) {
             SKGServices::SKGUnitInfo primary = m_currentBankDocument->getPrimaryUnit();
