@@ -41,6 +41,8 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
 
     ui.setupUi(this);
 
+    ui.kUseScheduledOperation->hide();
+
     ui.kPeriodLbl->setText(i18n("%1:", iDocument->getDisplay("t_period")));
     ui.kYearLbl->setText(i18n("%1:", iDocument->getDisplay("i_year")));
     ui.kMonthLbl->setText(i18n("%1:", iDocument->getDisplay("i_month")));
@@ -150,7 +152,11 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
     //Add Standard KDE Icons to buttons to Operations
     ui.kModifyBtn->setIcon(KIcon("dialog-ok-apply"));
     ui.kAddBtn->setIcon(KIcon("list-add"));
-    ui.kProcessBtn->setIcon(KIcon("system-run"));
+    QAction* processAction = SKGMainPanel::getMainPanel()->getGlobalAction("tool_process_budget_rules");
+    if (processAction) {
+        ui.kProcessBtn->setIcon(processAction->icon());
+        connect(ui.kProcessBtn, SIGNAL(clicked(bool)), processAction, SLOT(trigger()));
+    }
 
     {
         SKGWidgetSelector::SKGListQWidget list;
@@ -308,24 +314,6 @@ void SKGBudgetPluginWidget::onBtnModeClicked(int mode)
     onCreatorModified();
 }
 
-void SKGBudgetPluginWidget::onProcessRules()
-{
-    SKGError err;
-    _SKGTRACEINRC(10, "SKGBudgetPluginWidget::onProcessRules", err);
-
-    {
-        SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Process budget rules")  , err);
-        err = SKGBudgetRuleObject::processAllRules(static_cast<SKGDocumentBank*>(getDocument()));
-    }
-    //status bar
-    if (!err) {
-        err = SKGError(0, i18nc("Successful message after an user action", "Budget rules processed"));
-    } else err.addError(ERR_FAIL, i18nc("Error message", "Budget rules failed"));
-
-    //Display error
-    SKGMainPanel::displayErrorMessage(err);
-}
-
 void SKGBudgetPluginWidget::onAddClicked()
 {
     SKGError err;
@@ -374,6 +362,7 @@ void SKGBudgetPluginWidget::onAddClicked()
                 if (ui.kAutoBudgetCheck->isChecked()) err = SKGBudgetObject::createAutomaticBudget((SKGDocumentBank*) getDocument(),
                             ui.kYearAuto->value(),
                             ui.kYearAutoBase->value(),
+                            ui.kUseScheduledOperation->isChecked(),
                             ui.kRemovePrevious->isChecked());
                 if (!err) err = getDocument()->stepForward(1);
 
@@ -404,7 +393,7 @@ void SKGBudgetPluginWidget::onUpdateClicked()
     if (ui.kWidgetSelector->getSelectedMode() == 2) {
         {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget rule update"), err);
-            SKGBudgetRuleObject rule = selection.at(0);
+            SKGBudgetRuleObject rule(selection.at(0));
             err = updateBudgetRule(rule);
         }
 
@@ -417,7 +406,7 @@ void SKGBudgetPluginWidget::onUpdateClicked()
             int nb = selection.count();
             SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget update"), err, nb);
             for (int i = 0; !err && i < nb; ++i) {
-                SKGBudgetObject budget = selection.at(i);
+                SKGBudgetObject budget(selection.at(i));
                 int mode = ui.kPeriod->currentIndex();
                 if (mode == 1) { //Yearly
                     err = updateBudget(budget, 0);
@@ -494,48 +483,6 @@ SKGError SKGBudgetPluginWidget::updateBudgetRule(SKGBudgetRuleObject& iRule)
     if (!err) err = iRule.save();
     return err;
 }
-void SKGBudgetPluginWidget::open(const SKGBudgetObject& iBudget) //TODO: use open of operations
-{
-    _SKGTRACEIN(10, "SKGBudgetPluginWidget::open");
-
-    //Build where clause and title
-    QString y = SKGServices::intToString(iBudget.getYear());
-    QString m = SKGServices::intToString(iBudget.getMonth());
-    if (m.length() == 1) m = '0' % m;
-
-    QString wc = "i_IDCATEGORY IN (SELECT bc.id_category FROM budgetcategory bc WHERE bc.id=" % SKGServices::intToString(iBudget.getID()) % ") AND "
-                 "STRFTIME('%Y', d_date)='" % y % '\'';
-    if (m != "00") wc += " AND STRFTIME('%m', d_date)='" % m % '\'';
-    QString title = i18nc("Noun, a list of items", "Operations assigned to budget");
-
-    //Open
-    if (QApplication::keyboardModifiers() &Qt::ControlModifier && QApplication::keyboardModifiers() &Qt::ShiftModifier) {
-        //Call debug plugin
-        QDomDocument doc("SKGML");
-        QDomElement root = doc.createElement("parameters");
-        doc.appendChild(root);
-        root.setAttribute("sqlOrder", "SELECT * from v_operation_consolidated WHERE " % wc);
-
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Debug plugin"), -1, doc.toString());
-    } else {
-        //Call operation plugin
-        QDomDocument doc("SKGML");
-        doc.setContent(iBudget.getDocument()->getParameter("SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS"));
-        QDomElement root = doc.documentElement();
-        if (root.isNull()) {
-            root = doc.createElement("parameters");
-            doc.appendChild(root);
-        }
-
-        root.setAttribute("operationTable", "v_operation_consolidated");
-        root.setAttribute("operationWhereClause", wc);
-        root.setAttribute("title", title);
-        root.setAttribute("title_icon", "view-income-categories");
-        root.setAttribute("currentPage", "-1");
-
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
-    }
-}
 
 void SKGBudgetPluginWidget::onCreatorModified()
 {
@@ -559,7 +506,7 @@ void SKGBudgetPluginWidget::onSelectionChanged()
     int mode = ui.kWidgetSelector->getSelectedMode();
     if (nb) {
         if (m_objectModel->getRealTable() == "budget") {
-            SKGBudgetObject budget = objs.at(0);
+            SKGBudgetObject budget(objs.at(0));
             ui.kYear->setValue(budget.getYear());
             ui.kMonth->setValue(budget.getMonth());
             ui.kAmountEdit->setValue(budget.getBudgetedAmount());
@@ -569,7 +516,7 @@ void SKGBudgetPluginWidget::onSelectionChanged()
 
             if (mode > 0) ui.kWidgetSelector->setSelectedMode(0);
         } else {
-            SKGBudgetRuleObject rule = objs.at(0);
+            SKGBudgetRuleObject rule(objs.at(0));
             ui.kYearCheck->setChecked(rule.isYearConditionEnabled());
             ui.kYearRule->setValue(rule.getBudgetYear());
             ui.kMonthCheck->setChecked(rule.isMonthConditionEnabled());
@@ -620,7 +567,7 @@ void SKGBudgetPluginWidget::refreshInfoZone()
         double modified = 0;
         int nb = selection.count();
         for (int i = 0; i < nb; ++i) {
-            SKGBudgetObject budget = selection.at(i);
+            SKGBudgetObject budget(selection.at(i));
             budgeted += budget.getBudgetedAmount();
             modified += budget.getBudgetedModifiedAmount();
         }
