@@ -40,7 +40,7 @@ K_PLUGIN_FACTORY(SKGCalculatorPluginFactory, registerPlugin<SKGCalculatorPlugin>
  */
 K_EXPORT_PLUGIN(SKGCalculatorPluginFactory("skrooge_calculator", "skrooge_calculator"))
 
-SKGCalculatorPlugin::SKGCalculatorPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGCalculatorPlugin::SKGCalculatorPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
     SKGTRACEIN(10, "SKGCalculatorPlugin::SKGCalculatorPlugin");
 }
@@ -76,7 +76,7 @@ QString SKGCalculatorPlugin::getDashboardWidgetTitle(int iIndex)
     return "";
 }
 
-SKGWidget* SKGCalculatorPlugin::getDashboardWidget(int iIndex)
+SKGBoardWidget* SKGCalculatorPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGInterestBoardWidget(m_currentBankDocument);
     return NULL;
@@ -119,48 +119,38 @@ bool SKGCalculatorPlugin::isInPagesChooser() const
 {
     return true;
 }
-SKGAdviceList SKGCalculatorPlugin::advice() const
+SKGAdviceList SKGCalculatorPlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEIN(10, "SKGCalculatorPlugin::advice");
     SKGAdviceList output;
 
     //Search investment accounts without interest rate
-    SKGObjectBase::SKGListSKGObjectBase accounts;
-    m_currentBankDocument->getObjects("account", "t_type='I' AND NOT EXISTS (SELECT 1 FROM interest WHERE interest.rd_account_id=account.id)", accounts);
-    int nb = accounts.count();
-    for (int i = 0; i < nb; ++i) {
-        SKGAccountObject account = accounts.at(i);
-        SKGAdvice ad;
-        ad.setUUID("skgcalculatorplugin_nointerest|" % account.getName());
-        ad.setPriority(3);
-        ad.setShortMessage(i18nc("User did not define an interest rate on an investment account", "No interest rate defined for account '%1'", account.getName()));
-        ad.setLongMessage(i18nc("User did not define an interest rate on an investment account", "Your investment account '%1' doesn't have interest rate defined", account.getName()));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Link allowing user to open a new tab for defining interests parameters", "Open interest page"));
-        ad.setAutoCorrections(autoCorrections);
-        output.push_back(ad);
+    if (!iIgnoredAdvice.contains("skgcalculatorplugin_nointerest")) {
+        SKGObjectBase::SKGListSKGObjectBase accounts;
+        m_currentBankDocument->getObjects("account", "t_type='I' AND t_close='N' AND NOT EXISTS (SELECT 1 FROM interest WHERE interest.rd_account_id=account.id)", accounts);
+        int nb = accounts.count();
+        for (int i = 0; i < nb; ++i) {
+            SKGAccountObject account(accounts.at(i));
+            SKGAdvice ad;
+            ad.setUUID("skgcalculatorplugin_nointerest|" % account.getName());
+            ad.setPriority(3);
+            ad.setShortMessage(i18nc("User did not define an interest rate on an investment account", "No interest rate defined for account '%1'", account.getName()));
+            ad.setLongMessage(i18nc("User did not define an interest rate on an investment account", "Your investment account '%1' doesn't have interest rate defined", account.getName()));
+            QStringList autoCorrections;
+            autoCorrections.push_back(i18nc("Link allowing user to open a new tab for defining interests parameters", "Open interest page"));
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
     }
     return output;
 }
 
-SKGError SKGCalculatorPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
+SKGError SKGCalculatorPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgcalculatorplugin_nointerest|"))) {
         //Get parameters
         QString account = iAdviceIdentifier.right(iAdviceIdentifier.length() - 31);
-
-        //Call operation plugin
-        QDomDocument doc("SKGML");
-        doc.setContent(m_currentBankDocument->getParameter("SKGCALCULATOR_DEFAULT_PARAMETERS"));
-        QDomElement root = doc.documentElement();
-        if (root.isNull()) {
-            root = doc.createElement("parameters");
-            doc.appendChild(root);
-        }
-
-        root.setAttribute("currentPage", "0");
-        root.setAttribute("account", account);
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge calculator plugin"), -1, doc.toString());
+        SKGMainPanel::getMainPanel()->openPage("skg://skrooge_calculator_plugin/?currentPage=0&account=" % SKGServices::encodeForUrl(account));
         return SKGError();
     }
 
