@@ -21,15 +21,14 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
-#include "ui_skginterestpluginwidget_board.h"
-#include "skgwidget.h"
+#include "skgboardwidget.h"
 
 class KAction;
 
 /**
  * This file is Skrooge plugin for interest computation
  */
-class SKGInterestBoardWidget : public SKGWidget
+class SKGInterestBoardWidget : public SKGBoardWidget
 {
     Q_OBJECT
 
@@ -70,9 +69,9 @@ private Q_SLOTS:
     void dataModified(const QString& iTableName = "", int iIdTransaction = 0);
 
 private:
-    Q_DISABLE_COPY(SKGInterestBoardWidget);
+    Q_DISABLE_COPY(SKGInterestBoardWidget)
 
-    Ui::skginterestplugin_board ui;
+    QLabel* m_label;
 };
 
 #endif // SKGINTERESTBOARDWIDGET_H
