@@ -252,7 +252,7 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
     if (!iIgnoredAdvice.contains("skgcategoriesplugin_unused")) {
         SKGTRACEIN(10, "SKGCategoriesPlugin::advice-skgcategoriesplugin_unused");
         bool exist = false;
-        m_currentBankDocument->existObjects("v_category_display", "i_NBOPERATIONS=0 AND i_SUMNBOPERATIONS=0", exist); //i_NBOPERATIONS=0 is there to improve performances
+        m_currentBankDocument->existObjects("v_category_used2", "t_ISUSEDCASCADE='N'", exist);
         if (exist) {
             SKGAdvice ad;
             ad.setUUID("skgcategoriesplugin_unused");
