@@ -329,11 +329,8 @@ void SKGImportExportPlugin::refresh()
 
                         {
                             //Import
-                            err = importbackends();
+                            importbackends();
                         }
-
-                        //Display error
-                        SKGMainPanel::displayErrorMessage(err);
                     }
                 }
             }
@@ -346,6 +343,13 @@ SKGError SKGImportExportPlugin::importbackends()
     SKGError err;
     SKGTRACEINRC(10, "SKGImportExportPlugin::importbackends", err);
     if (m_currentBankDocument) {
+        //Check if already in a transaction
+        if (!m_currentBankDocument->checkExistingTransaction()) {
+            //Repeat later
+            QTimer::singleShot(300, this, SLOT(importbackends()));
+            return err;
+        }
+
         //Get backends list to used
         QStringList backends = SKGServices::splitCSVLine(skgimportexport_settings::backends());
         int nbBackends = backends.count();
@@ -500,7 +504,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
 
                     if (m_install) {
                         QMap< QString, QString > parameters = imp1.getImportParameters();
-                        parameters["install"] = 'Y';
+                        parameters["install_sunriise"] = 'Y';
                         imp1.setImportParameters(parameters);
                     }
 
@@ -523,7 +527,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
 
                             //Load file
                             if (!pwd.isEmpty()) {
-                                QMap<QString, QString> parameters;
+                                QMap<QString, QString> parameters = imp1.getImportParameters();;
                                 parameters["password"] = pwd;
                                 imp1.setImportParameters(parameters);
                                 err = imp1.importFile();
@@ -642,15 +646,17 @@ void SKGImportExportPlugin::findTransfers()
         }
 
         //status bar
-        if (!err) err = SKGError(0, i18np("Document successfully processed. %1 operation merged.",
-                                              "Document successfully processed. %1 operations merged.", NbOperationsMerged));
-        else err.addError(ERR_FAIL, i18nc("Error message", "Processing failed."));
+        if (!err) {
+            if (NbOperationsMerged) err = SKGError(0, i18np("Document successfully processed. %1 transfer created.",
+                                                       "Document successfully processed. %1 transfers created.", NbOperationsMerged));
+            else err = m_currentBankDocument->sendMessage(i18nc("Information message", "No transfers found"));
+        } else err.addError(ERR_FAIL, i18nc("Error message", "Processing failed."));
 
         //Display error
         SKGMainPanel::displayErrorMessage(err);
 
         //Open last modified operations if setting activated
-        if (!err) openLastModifiedIfSetting();
+        if (!err && NbOperationsMerged) openLastModifiedIfSetting();
     }
 }
 
