@@ -68,8 +68,10 @@ private:
 
     Ui::skgoperationplugin_board ui;
 
+    KAction* m_menuOpen;
     KAction* m_menuTransfert;
     KAction* m_menuTracked;
+    KAction* m_menuSuboperation;
 };
 
 #endif // SKGOPERATIONBOARDWIDGET_H
