@@ -150,7 +150,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     //------------
     m_openDuplicate = new KAction(KIcon("skrooge_duplicate", NULL, overlayopen), i18nc("Verb", "Open potential duplicates..."), this);
     m_openDuplicate->setData(QString("skg://skrooge_operation_plugin/?title_icon=skrooge_duplicate&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Operations potentially duplicated")) %
-                                     "&operationWhereClause=" % SKGServices::encodeForUrl("id in (SELECT o1.id FROM v_operation o1 WHERE EXISTS (SELECT 1 FROM v_operation o2 WHERE o1.id<>o2.id AND o1.t_template='N' AND o2.t_template='N' AND o1.d_date=o2.d_date  AND ABS(o1.f_CURRENTAMOUNT-o2.f_CURRENTAMOUNT)<" % SKGServices::doubleToString(EPSILON) % " AND o1.rd_account_id=o2.rd_account_id AND o1.rc_unit_id=o2.rc_unit_id AND (o1.t_status='N' OR o2.t_status='N')))")));
+                                     "&operationWhereClause=" % SKGServices::encodeForUrl("id in (SELECT o1.id FROM v_operation o1 WHERE EXISTS (SELECT 1 FROM v_operation o2 WHERE o1.id<>o2.id AND o1.t_template='N' AND o2.t_template='N' AND o1.d_date=o2.d_date  AND ABS(o1.f_CURRENTAMOUNT-o2.f_CURRENTAMOUNT)<" % SKGServices::doubleToString(EPSILON) % " AND o1.rd_account_id=o2.rd_account_id AND o1.rc_unit_id=o2.rc_unit_id AND (o1.t_status<>'Y' OR o2.t_status<>'Y')))")));
     connect(m_openDuplicate, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
     m_openDuplicate->setShortcut(Qt::META + Qt::Key_D);
     registerGlobalAction("view_open_duplicates", m_openDuplicate);
@@ -909,11 +909,11 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
-    //Too many money on a current account
+    //Too much money in your account
     if (!iIgnoredAdvice.contains("skgoperationplugin_too_much_money")) {
         SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_too_much_money");
         SKGStringListList result;
-        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name, f_RATE FROM v_account_display WHERE t_close='N' AND f_RATE>0 ORDER BY f_RATE DESC", result);
+        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name, f_RATE FROM v_account_display WHERE t_close='N' AND f_RATE>0 AND (t_maxamount_enabled='N' OR f_CURRENTAMOUNT<f_maxamount*0.9) ORDER BY f_RATE DESC", result);
         int nb = result.count();
         if (nb > 1) {
             //Get better interest account
@@ -921,7 +921,10 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
             QString rate = result.at(1).at(1);
 
             //Get accounts with too much money
-            m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name FROM v_account_display WHERE f_RATE<" % rate % " AND t_type='C' AND t_close='N' AND f_CURRENTAMOUNT>-2*(SELECT TOTAL(s.f_CURRENTAMOUNT) FROM v_operation_display s WHERE s.rd_account_id=v_account_display.id AND s.t_TYPEEXPENSE='-' AND s.d_DATEMONTH = (SELECT strftime('%Y-%m',date('now','start of month', '-1 MONTH'))))", result);
+            m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name FROM v_account_display WHERE t_close='N' AND ("
+                    //Interest are computed on amount over the limit too, not need to transfer them "(t_maxamount_enabled='Y' AND f_CURRENTAMOUNT>f_maxamount) OR "
+                    "(f_RATE<" % rate % " AND t_type='C' AND f_CURRENTAMOUNT>-2*(SELECT TOTAL(s.f_CURRENTAMOUNT) FROM v_operation_display s WHERE s.rd_account_id=v_account_display.id AND s.t_TYPEEXPENSE='-' AND s.d_DATEMONTH = (SELECT strftime('%Y-%m',date('now','start of month', '-1 MONTH')))))"
+                    ")", result);
             nb = result.count();
             for (int i = 1; i < nb; ++i) { //Ignore header
                 //Get parameters
@@ -936,6 +939,50 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
             }
         }
     }
+
+    //Not enough money in your account
+    if (!iIgnoredAdvice.contains("skgoperationplugin_minimum_limit")) {
+        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_minimum_limit");
+        SKGStringListList result;
+
+        //Get accounts with amount close or below the minimum limit
+        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name FROM v_account_display WHERE t_close='N' AND t_minamount_enabled='Y' AND f_CURRENTAMOUNT<f_minamount", result);
+        int nb = result.count();
+        for (int i = 1; i < nb; ++i) { //Ignore header
+            //Get parameters
+            QString account = result.at(i).at(0);
+
+            SKGAdvice ad;
+            ad.setUUID("skgoperationplugin_minimum_limit|" % account);
+            ad.setPriority(9);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Not enough money in your account '%1'", account));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "The amount of this account is below the minimum limit. You should replenish it."));
+            output.push_back(ad);
+        }
+    }
+
+    //Not enough money in your account
+    if (!iIgnoredAdvice.contains("skgoperationplugin_close_minimum_limit")) {
+        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_close_minimum_limit");
+        SKGStringListList result;
+
+        //Get accounts with amount close or below the minimum limit
+        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name FROM v_account_display WHERE t_close='N' AND t_minamount_enabled='Y' AND t_maxamount_enabled='Y'"
+                " AND f_CURRENTAMOUNT>=f_minamount AND f_CURRENTAMOUNT<=f_minamount+0.1*(f_maxamount-f_minamount)", result);
+        int nb = result.count();
+        for (int i = 1; i < nb; ++i) { //Ignore header
+            //Get parameters
+            QString account = result.at(i).at(0);
+
+            SKGAdvice ad;
+            ad.setUUID("skgoperationplugin_close_minimum_limit|" % account);
+            ad.setPriority(5);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Your account '%1' is close to the minimum limit", account));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "The amount of this account is close to the minimum limit. You should take care of it."));
+            output.push_back(ad);
+        }
+    }
+
     return output;
 }
 
