@@ -51,7 +51,7 @@ K_PLUGIN_FACTORY(SKGReportPluginFactory, registerPlugin<SKGReportPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGReportPluginFactory("skrooge_report", "skrooge_report"))
 
-SKGReportPlugin::SKGReportPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGReportPlugin::SKGReportPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
     SKGTRACEIN(10, "SKGReportPlugin::SKGReportPlugin");
 }
@@ -77,11 +77,17 @@ bool SKGReportPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     QStringList overlayopen;
     overlayopen.push_back("skg_open");
     m_openReportAction = new KAction(KIcon("view-investment", NULL, overlayopen), i18nc("Verb", "Open report..."), this);
-    connect(m_openReportAction, SIGNAL(triggered(bool)), this, SLOT(actionOpenReport()));
-    actionCollection()->addAction(QLatin1String("open_report"), m_openReportAction);
+    connect(m_openReportAction, SIGNAL(triggered(bool)), this, SLOT(onOpenReport()));
     m_openReportAction->setShortcut(Qt::META + Qt::Key_R);
+    registerGlobalAction("open_report", m_openReportAction);
 
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("open_report", m_openReportAction);
+    //---------------
+    KAction* act = new KAction(KIcon("security-low", NULL, overlayopen), i18nc("Verb", "Open very old operations..."), this);
+    act->setData(QString("skg://skrooge_operation_plugin/?title_icon=security-low&title=" %
+                         SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Very old operations")) %
+                         "&operationWhereClause=" % SKGServices::encodeForUrl("d_date<=(SELECT date('now', '-50 year')) AND d_date<>'0000-00-00'")));
+    connect(act, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
+    registerGlobalAction("view_open_very_old_operations", act);
     return true;
 }
 
@@ -112,7 +118,7 @@ QString SKGReportPlugin::getDashboardWidgetTitle(int iIndex)
     return "";
 }
 
-SKGWidget* SKGReportPlugin::getDashboardWidget(int iIndex)
+SKGBoardWidget* SKGReportPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGReportBoardWidget(m_currentBankDocument);
     return NULL;
@@ -171,10 +177,10 @@ bool SKGReportPlugin::isInPagesChooser() const
     return true;
 }
 
-void SKGReportPlugin::actionOpenReport()
+void SKGReportPlugin::onOpenReport()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGReportPlugin::actionOpenReport", err);
+    SKGTRACEINRC(10, "SKGReportPlugin::onOpenReport", err);
     if (SKGMainPanel::getMainPanel()) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
 
@@ -188,7 +194,7 @@ void SKGReportPlugin::actionOpenReport()
                 title = i18nc("Noun, a list of items", "Operations of account ");
 
                 for (int i = 0; i < nb; ++i) {
-                    SKGAccountObject tmp = selection.at(i);
+                    SKGAccountObject tmp(selection.at(i));
                     if (i) {
                         wc += ',';
                         title += ',';
@@ -202,7 +208,7 @@ void SKGReportPlugin::actionOpenReport()
                 title = i18nc("Noun, a list of items", "Operations with Unit equal to ");
 
                 for (int i = 0; i < nb; ++i) {
-                    SKGUnitObject tmp = selection.at(i);
+                    SKGUnitObject tmp(selection.at(i));
                     if (i) {
                         wc += ',';
                         title += ',';
@@ -217,7 +223,7 @@ void SKGReportPlugin::actionOpenReport()
                 title = i18nc("Noun, a list of items", "Operations with Category equal to ");
 
                 for (int i = 0; i < nb; ++i) {
-                    SKGCategoryObject tmp = selection.at(i);
+                    SKGCategoryObject tmp(selection.at(i));
                     if (i) {
                         wc += ',';
                         wc2 += " OR ";
@@ -233,7 +239,7 @@ void SKGReportPlugin::actionOpenReport()
                 title = i18nc("Noun, a list of items", "Operations followed by ");
 
                 for (int i = 0; i < nb; ++i) {
-                    SKGTrackerObject tmp = selection.at(i);
+                    SKGTrackerObject tmp(selection.at(i));
                     if (i) {
                         wc += ',';
                         title += ',';
@@ -247,7 +253,7 @@ void SKGReportPlugin::actionOpenReport()
                 title = i18nc("Noun, a list of items", "Operations assigned to ");
 
                 for (int i = 0; i < nb; ++i) {
-                    SKGPayeeObject tmp = selection.at(i);
+                    SKGPayeeObject tmp(selection.at(i));
                     if (i) {
                         wc += ',';
                         title += ',';
@@ -271,7 +277,7 @@ void SKGReportPlugin::actionOpenReport()
                 title = i18nc("Noun, a list of items", "Operations corresponding to rule ");
 
                 for (int i = 0; i < nb; ++i) {
-                    SKGRuleObject tmp = selection.at(i);
+                    SKGRuleObject tmp(selection.at(i));
                     QString ruleWc = tmp.getSelectSqlOrder();
                     if (!ruleWc.isEmpty()) {
                         if (!wc.isEmpty()) {
@@ -285,64 +291,33 @@ void SKGReportPlugin::actionOpenReport()
             }
 
             //Call report plugin
-            QDomDocument doc("SKGML");
-            if (m_currentBankDocument) doc.setContent(m_currentBankDocument->getParameter("SKGREPORT_DEFAULT_PARAMETERS"));
-            QDomElement root = doc.documentElement();
-            if (root.isNull()) {
-                root = doc.createElement("parameters");
-                doc.appendChild(root);
-            }
-
-            root.setAttribute("operationWhereClause", wc);
-            root.setAttribute("title", title);
-            root.setAttribute("title_icon", icon());
-            root.setAttribute("period", "0");
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge report plugin"), -1, doc.toString());
+            SKGMainPanel::getMainPanel()->openPage("skg://skrooge_report_plugin/?period=0&title_icon=" % icon() % "&title=" % SKGServices::encodeForUrl(title) % "&operationWhereClause=" % SKGServices::encodeForUrl(wc));
         }
     }
 }
 
-SKGAdviceList SKGReportPlugin::advice() const
+SKGAdviceList SKGReportPlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGTRACEIN(10, "SKGOperationPlugin::advice");
+    SKGTRACEIN(10, "SKGReportPlugin::advice");
     SKGAdviceList output;
 
     //Very old operation
-    bool exist = false;
-    m_currentBankDocument->existObjects("operation", "d_date<=date('now', '-50 year') AND d_date<>'0000-00-00'", exist);
-    if (exist) {
-        SKGAdvice ad;
-        ad.setUUID("skgreportplugin_veryold");
-        ad.setPriority(3);
-        ad.setShortMessage(i18nc("Advice on making the best (short)", "Some operations are very old"));
-        ad.setLongMessage(i18nc("Advice on making the best (long)", "For performances reasons, very old operations are not taken into account in graph report. Check if these operations are normal."));
-        QStringList autoCorrections;
-        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open very old operations"));
-        ad.setAutoCorrections(autoCorrections);
-        output.push_back(ad);
+    if (!iIgnoredAdvice.contains("skgreportplugin_veryold")) {
+        bool exist = false;
+        m_currentBankDocument->existObjects("operation", "d_date<=(SELECT date('now', '-50 year')) AND d_date<>'0000-00-00'", exist);
+        if (exist) {
+            SKGAdvice ad;
+            ad.setUUID("skgreportplugin_veryold");
+            ad.setPriority(3);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Some operations are very old"));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "For performances reasons, very old operations are not taken into account in graph report. Check if these operations are normal."));
+            QStringList autoCorrections;
+            autoCorrections.push_back("skg://view_open_very_old_operations");
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
     }
     return output;
 }
 
-SKGError SKGReportPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
-{
-    if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgreportplugin_veryold"))) {
-        //Call operation plugin
-        QDomDocument doc("SKGML");
-        doc.setContent(m_currentBankDocument->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
-        QDomElement root = doc.documentElement();
-        if (root.isNull()) {
-            root = doc.createElement("parameters");
-            doc.appendChild(root);
-        }
-
-        root.setAttribute("operationWhereClause", "d_date<=date('now', '-50 year') AND d_date<>'0000-00-00'");
-        root.setAttribute("title", i18nc("Noun, a list of items", "Very old operations"));
-        root.setAttribute("title_icon", "security-low");
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
-        return SKGError();
-    }
-    return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
-}
-
 #include "skgreportplugin.moc"
