@@ -908,12 +908,14 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 int forecastMode = ui.kForecastCmb->itemData(ui.kForecastCmb->currentIndex()).toInt();
 
                 //Compute forecast on scheduled operations
+                bool transactionToRollback = false;
                 if (forecastMode == 1 || forecastMode == 4) {
                     //Create operations
                     QDate lastDate = QDate::currentDate().addDays(ui.kForecastValue->value() * 365.0 / ui.kForecastValue->maximum());
                     if (forecastMode == 1) {
                         //Create scheduled operations
                         doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create scheduled operations"));
+                        transactionToRollback = true;
                         int nbInserted = 0;
                         SKGRecurrentOperationObject::process(doc, nbInserted, true, lastDate);
                     } else {
@@ -939,6 +941,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
 
 
                                 doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create budgeted operations"), nb);
+                                transactionToRollback = true;
                                 for (int i = 0; !err && i < nb; ++i) {
                                     SKGBudgetObject budget(budgets.at(i));
 
@@ -1033,10 +1036,10 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     }
                 }
 
-                if (forecastMode == 1 || forecastMode == 4) {
-                    //Rollback create operations
-                    doc->endTransaction(false);
+                //Rollback create operations
+                if (transactionToRollback) doc->endTransaction(false);
 
+                if (forecastMode == 1 || forecastMode == 4) {
                     //Compute nb date in futur
                     if (nbLines) {
                         QStringList line1 = table.at(0);
