@@ -399,9 +399,7 @@ SKGError SKGSearchPlugin::executeAdviceCorrection(const QString& iAdviceIdentifi
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgsearchplugin_alarm|"))) {
         //Get parameters
         QString id = iAdviceIdentifier.right(iAdviceIdentifier.length() - 22);
-        SKGRuleObject rule(m_currentBankDocument, SKGServices::stringToInt(id));
-        rule.load();
-        SKGSearchPluginWidget::open(rule); //FIXME //TODO
+        SKGSearchPluginWidget::open(SKGRuleObject(m_currentBankDocument, SKGServices::stringToInt(id)));
         return SKGError();
     }
 
