@@ -119,7 +119,7 @@ SKGAdviceList SKGTrackerPlugin::advice(const QStringList& iIgnoredAdvice)
         int nb = result.count();
         for (int i = 1; i < nb; ++i) { //Ignore header
             SKGAdvice ad;
-            ad.setUUID("skgtrackerplugin_old");
+            ad.setUUID("skgtrackerplugin_old|" % result.at(i).at(0));
             ad.setPriority(2);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "'%1' is an old tracker", result.at(i).at(0)));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "This tracker does not contain recent operation. You may want to close it if you do not intend to add other operations"));
