@@ -32,13 +32,13 @@ class SKGMainPanel;
 class SKGTrackerPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGTrackerPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGTrackerPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -105,21 +105,12 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advice() const;
-
-    /**
-     * Must be implemented to execute the automatic correction for the advice.
-     * @param iAdviceIdentifier the identifier of the advice
-     * @param iSolution the identifier of the possible solution
-     * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
-     *   @see SKGError
-     */
-    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const;
+    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice);
 
 private Q_SLOTS:
 
 private:
-    Q_DISABLE_COPY(SKGTrackerPlugin);
+    Q_DISABLE_COPY(SKGTrackerPlugin)
 
 
     SKGDocument* m_currentBankDocument;
