@@ -670,22 +670,26 @@ bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, in
                 err = obj.setClosed((Qt::CheckState) value.toInt() == Qt::Checked);
                 if (!err) err = obj.save();
             } else if (m_operationTable) {
-                SKGOperationObject obj(getObject(index));
-                SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Change operation status"), err);
-                SKGOperationObject::OperationStatus statusinitial = obj.getStatus();
-                SKGOperationObject::OperationStatus t_status = statusinitial;
-                if (QApplication::keyboardModifiers() &Qt::ControlModifier) {
-                    //2747379: NONE ==> CHECKED, POINTED ==> CHECKED, CHECKED ==> CHECKED
-                    t_status = SKGOperationObject::CHECKED ;
-                    //t_status= ( t_status==SKGOperationObject::POINTED ? SKGOperationObject::NONE : ( t_status==SKGOperationObject::CHECKED ? SKGOperationObject::POINTED : SKGOperationObject::NONE ) );
-                } else {
-                    //2747379: NONE ==> POINTED, POINTED ==> NONE, CHECKED ==> POINTED
-                    t_status = (t_status == SKGOperationObject::NONE ? SKGOperationObject::POINTED : (t_status == SKGOperationObject::POINTED ? SKGOperationObject::NONE : SKGOperationObject::POINTED));
-                    //t_status=(t_status==SKGOperationObject::POINTED ? SKGOperationObject::CHECKED : (t_status==SKGOperationObject::CHECKED ? SKGOperationObject::CHECKED : SKGOperationObject::POINTED ));
-                }
-                if (t_status != statusinitial) {
-                    err = obj.setStatus(t_status);
-                    if (!err) err = obj.save();
+                //Get the real object, not the object from the view
+                SKGObjectBase* objtmp = getObjectPointer(index);
+                if (objtmp) {
+                    SKGOperationObject obj = SKGOperationObject(objtmp->getDocument(), objtmp->getID());
+                    SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Change operation status"), err);
+                    SKGOperationObject::OperationStatus statusinitial = obj.getStatus();
+                    SKGOperationObject::OperationStatus t_status = statusinitial;
+                    if (QApplication::keyboardModifiers() &Qt::ControlModifier) {
+                        //2747379: NONE ==> CHECKED, POINTED ==> CHECKED, CHECKED ==> CHECKED
+                        t_status = SKGOperationObject::CHECKED ;
+                        //t_status= ( t_status==SKGOperationObject::POINTED ? SKGOperationObject::NONE : ( t_status==SKGOperationObject::CHECKED ? SKGOperationObject::POINTED : SKGOperationObject::NONE ) );
+                    } else {
+                        //2747379: NONE ==> POINTED, POINTED ==> NONE, CHECKED ==> POINTED
+                        t_status = (t_status == SKGOperationObject::NONE ? SKGOperationObject::POINTED : (t_status == SKGOperationObject::POINTED ? SKGOperationObject::NONE : SKGOperationObject::POINTED));
+                        //t_status=(t_status==SKGOperationObject::POINTED ? SKGOperationObject::CHECKED : (t_status==SKGOperationObject::CHECKED ? SKGOperationObject::CHECKED : SKGOperationObject::POINTED ));
+                    }
+                    if (t_status != statusinitial) {
+                        err = obj.setStatus(t_status);
+                        if (!err) err = obj.save();
+                    }
                 }
             } else if (m_recurrentoperationTable) {
                 QString att = m_listAttibutes[index.column()];
