@@ -144,7 +144,7 @@ protected Q_SLOTS:
     virtual QString getAttributeForGrouping(const SKGObjectBase& iObject, const QString& iAttribute) const;
 
 private:
-    Q_DISABLE_COPY(SKGObjectModel);
+    Q_DISABLE_COPY(SKGObjectModel)
 
     SKGServices::SKGUnitInfo m_cacheUnit;
     bool m_operationTable;
