@@ -156,21 +156,56 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* parent, SKGDocument* document, c
             m_kValue2 = cmbVal2;
         }
     } else  if (attType == SKGServices::DATE) {
-        SKGDateEdit* cmbVal1 = new SKGDateEdit(this);
-        if (cmbVal1) {
-            cmbVal1->setObjectName(QString::fromUtf8("cmbVal1"));
-            cmbVal1->setMinimumSize(QSize(100, 0));
+        if (iModeUpdate) {
+            SKGComboBox* cmbVal1 = new SKGComboBox(this);
+            if (cmbVal1) {
+                cmbVal1->setObjectName(QString::fromUtf8("cmbVal1"));
+                cmbVal1->setMinimumSize(QSize(100, 0));
+                cmbVal1->setEditable(true);
+                QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+                sizePolicy.setHorizontalStretch(0);
+                sizePolicy.setVerticalStretch(0);
+                sizePolicy.setHeightForWidth(cmbVal1->sizePolicy().hasHeightForWidth());
+                cmbVal1->setSizePolicy(sizePolicy);
 
-            horizontalLayout->addWidget(cmbVal1);
-            m_kValue1 = cmbVal1;
-        }
-        SKGDateEdit* cmbVal2 = new SKGDateEdit(this);
-        if (cmbVal2) {
-            cmbVal2->setObjectName(QString::fromUtf8("cmbVal2"));
-            cmbVal2->setMinimumSize(QSize(100, 0));
+                horizontalLayout->addWidget(cmbVal1);
+                m_kValue1 = cmbVal1;
+            }
 
-            horizontalLayout->addWidget(cmbVal2);
-            m_kValue2 = cmbVal2;
+            SKGComboBox* cmbVal2 = new SKGComboBox(this);
+            if (cmbVal2) {
+                cmbVal2->setObjectName(QString::fromUtf8("cmbVal2"));
+                cmbVal2->setMinimumSize(QSize(100, 0));
+                cmbVal2->setEditable(false);
+                QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+                sizePolicy.setHorizontalStretch(0);
+                sizePolicy.setVerticalStretch(0);
+                sizePolicy.setHeightForWidth(cmbVal2->sizePolicy().hasHeightForWidth());
+                cmbVal2->setSizePolicy(sizePolicy);
+                cmbVal2->addItems(QStringList() << "YYYYMMDD" << "MMDDYYYY" << "DDMMYYYY"
+                                  << "MM-DD-YY" << "DD-MM-YY" << "MM-DD-YYYY" << "DD-MM-YYYY" << "YYYY-MM-DD");
+
+                horizontalLayout->addWidget(cmbVal2);
+                m_kValue2 = cmbVal2;
+            }
+        } else {
+            SKGDateEdit* cmbVal1 = new SKGDateEdit(this);
+            if (cmbVal1) {
+                cmbVal1->setObjectName(QString::fromUtf8("cmbVal1"));
+                cmbVal1->setMinimumSize(QSize(100, 0));
+
+                horizontalLayout->addWidget(cmbVal1);
+                m_kValue1 = cmbVal1;
+            }
+
+            SKGDateEdit* cmbVal2 = new SKGDateEdit(this);
+            if (cmbVal2) {
+                cmbVal2->setObjectName(QString::fromUtf8("cmbVal2"));
+                cmbVal2->setMinimumSize(QSize(100, 0));
+
+                horizontalLayout->addWidget(cmbVal2);
+                m_kValue2 = cmbVal2;
+            }
         }
     } else  if (attType == SKGServices::BOOL || attType == SKGServices::TRISTATE) {
         QCheckBox* cmbVal1 = new QCheckBox(this);
@@ -238,7 +273,7 @@ void SKGPredicatCreator::onOperatorChanged()
     QString req;
     if (m_kOperator) req = m_kOperator->itemData(m_kOperator->currentIndex()).toString();
     if (m_kValue1) m_kValue1->setVisible(req.contains("#V1S#") || req.contains("#V1#"));
-    if (m_kValue2) m_kValue2->setVisible(req.contains("#V2S#") || req.contains("#V2#"));
+    if (m_kValue2) m_kValue2->setVisible(req.contains("#V2S#") || req.contains("#V2#") || req.contains("#DF#"));
     if (m_kAttributes) m_kAttributes->setVisible(req.contains("#ATT2#"));
 }
 
