@@ -22,7 +22,7 @@
 #include "skgpredicatcreatordesignerplugin.h"
 #include "skgpredicatcreator.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
