@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -65,21 +65,21 @@ void SKGProcessCreator::setXMLCondition(const QString& iXML)
     QDomElement root = doc.documentElement();
 
     // Remove all existing lines
-    for(int i = 0; ui.propertyLinesLayout->count(); i++) {
-        QLayoutItem*line = ui.propertyLinesLayout->takeAt(i);
-        if(line) line->widget()->deleteLater();
+    for (int i = 0; ui.propertyLinesLayout->count(); ++i) {
+        QLayoutItem* line = ui.propertyLinesLayout->takeAt(i);
+        if (line) line->widget()->deleteLater();
     }
     QDomNode l = root.firstChild();
-    while(!l.isNull()) {
+    while (!l.isNull()) {
         QDomElement elementl = l.toElement();
-        if(!elementl.isNull()) {
+        if (!elementl.isNull()) {
             //Add new line
-            SKGPropertyEditor*line = addLine();
+            SKGPropertyEditor* line = addLine();
 
             QDomNode n = elementl.firstChild();
-            while(!n.isNull()) {
+            while (!n.isNull()) {
                 QDomElement element = n.toElement();
-                if(!element.isNull()) {
+                if (!element.isNull()) {
                     QString attribute = element.attribute("attribute");
 
                     QDomDocument doc2("SKGML");
@@ -91,7 +91,7 @@ void SKGProcessCreator::setXMLCondition(const QString& iXML)
                     root2.setAttribute("att2", element.attribute("att2"));
                     root2.setAttribute("att2s", element.attribute("att2s"));
                     QString xml = doc2.toString();
-                    if(line) line->setXMLCondition(SKGPredicatCreator::getTextFromXml(xml));
+                    if (line) line->setXMLCondition(SKGPredicatCreator::getTextFromXml(xml));
                 }
                 n = n.nextSibling();
             }
