@@ -73,7 +73,7 @@ public Q_SLOTS:
     virtual void setupWidgets();
 
 private:
-    Q_DISABLE_COPY(SKGPropertyEditor);
+    Q_DISABLE_COPY(SKGPropertyEditor)
 
     Ui::skgpropertyeditor_base ui;
 
