@@ -22,7 +22,7 @@
 #include "skgunitcomboboxdesignerplugin.h"
 #include "skgunitcombobox.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
