@@ -74,7 +74,7 @@ SKGError SKGAccountObject::setInitialBalance(double iBalance, const SKGUnitObjec
         //Creation of new initial balance
         if (!err) {
             SKGOperationObject initialBalanceOp;
-            err = addOperation(initialBalanceOp);
+            err = addOperation(initialBalanceOp, true);
             if (!err) err = initialBalanceOp.setAttribute("d_date", "0000-00-00");
             if (!err) err = initialBalanceOp.setUnit(iUnit);
             if (!err) err = initialBalanceOp.setStatus(SKGOperationObject::CHECKED);
@@ -163,13 +163,13 @@ QString SKGAccountObject::getAgencyAddress() const
     return getAttribute("t_agency_address");
 }
 
-SKGError SKGAccountObject::addOperation(SKGOperationObject& oOperation)
+SKGError SKGAccountObject::addOperation(SKGOperationObject& oOperation, bool iForce)
 {
     SKGError err;
     if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGAccountObject::addOperation")));
     else {
         oOperation = SKGOperationObject(getDocument());
-        err = oOperation.setParentAccount(*this);
+        err = oOperation.setParentAccount(*this, iForce);
     }
     return err;
 }
@@ -286,6 +286,51 @@ bool SKGAccountObject::isBookmarked() const
     return (getAttribute("t_bookmarked") == "Y" ? true : false);
 }
 
+SKGError SKGAccountObject::maxLimitAmountEnabled(bool iEnabled)
+{
+    return setAttribute("t_maxamount_enabled", iEnabled ? "Y" : "N");
+
+}
+
+bool SKGAccountObject::isMaxLimitAmountEnabled() const
+{
+    return (getAttribute("t_maxamount_enabled") == "Y" ? true : false);
+}
+
+SKGError SKGAccountObject::setMaxLimitAmount(double iAmount)
+{
+    SKGError err = setAttribute("f_maxamount", SKGServices::doubleToString(iAmount));
+    if (!err && getMinLimitAmount() > iAmount) err = setMinLimitAmount(iAmount);
+    return err;
+}
+
+double SKGAccountObject::getMaxLimitAmount() const
+{
+    return SKGServices::stringToDouble(getAttribute("f_maxamount"));
+}
+
+SKGError SKGAccountObject::minLimitAmountEnabled(bool iEnabled)
+{
+    return setAttribute("t_minamount_enabled", iEnabled ? "Y" : "N");
+}
+
+bool SKGAccountObject::isMinLimitAmountEnabled() const
+{
+    return (getAttribute("t_minamount_enabled") == "Y" ? true : false);
+}
+
+SKGError SKGAccountObject::setMinLimitAmount(double iAmount)
+{
+    SKGError err = setAttribute("f_minamount", SKGServices::doubleToString(iAmount));
+    if (!err && getMaxLimitAmount() < iAmount) err = setMaxLimitAmount(iAmount);
+    return err;
+}
+
+double SKGAccountObject::getMinLimitAmount() const
+{
+    return SKGServices::stringToDouble(getAttribute("f_minamount"));
+}
+
 SKGError SKGAccountObject::getUnit(SKGUnitObject& oUnit) const
 {
     //Get initial amount
