@@ -232,8 +232,7 @@ SKGError SKGBudgetObject::process()
             if (!err) err = getDocument()->stepForward(i + 1);
         }
 
-        if (!err) err = getDocument()->endTransaction(true);
-        else  getDocument()->endTransaction(false);
+        if (!err) err = getDocument()->endTransaction(true); else  getDocument()->endTransaction(false);
     }
 
     return err;
