@@ -276,7 +276,7 @@ SKGError SKGImportExportManager::finalizeImportation()
         if (m_since_last_import && !err) {
             SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-deletebeforelastimport", err);
             err = m_document->executeSqliteOrder("DELETE FROM operation WHERE operation.t_imported='T' AND "
-                                                 "EXISTS(SELECT 1 FROM operation o INDEXED BY idx_operation_rd_account_id_t_imported WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND o.d_date>=operation.d_date)");
+                                                 "EXISTS(SELECT 1 FROM operation o INDEXED BY idx_operation_rd_account_id_t_imported WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND o.d_date>operation.d_date)");
         }
 
         //For performances
@@ -479,10 +479,7 @@ SKGError SKGImportExportManager::importFile()
                 err = pluginInterface->importFile();
             }
 
-            if (!err && !fileTreated) {
-                err.setReturnCode(ERR_NOTIMPL);
-                err.setMessage(i18nc("Error message",  "This import mode is not yet implemented"));
-            }
+            if (!err && !fileTreated)err.setReturnCode(ERR_NOTIMPL).setMessage(i18nc("Error message",  "This import mode is not yet implemented"));
         }
         if (!err) err = m_document->stepForward(2);
 
@@ -512,10 +509,7 @@ SKGError SKGImportExportManager::exportFile()
                 if (!err) err = SKGServices::upload(KUrl::fromLocalFile(getLocalFileName(false)), m_fileName);
             }
 
-            if (!err && !fileTreated) {
-                err.setReturnCode(ERR_NOTIMPL);
-                err.setMessage(i18nc("Error message",  "This export mode is not yet implemented"));
-            }
+            if (!err && !fileTreated) err.setReturnCode(ERR_NOTIMPL).setMessage(i18nc("Error message",  "This export mode is not yet implemented"));
         }
     }
 
@@ -650,7 +644,7 @@ SKGError SKGImportExportManager::anonymize()
     return err;
 }
 
-SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged)
+SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged, bool iOnCurrentlyImport)
 {
     SKGError err;
     SKGTRACEINRC(2, "SKGImportExportManager::findAndGroupTransfers", err);
@@ -661,6 +655,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged)
     if (m_document) {
         err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Find and group transfers"), 3);
         if (!err) {
+            if (!err) err = m_document->executeSqliteOrder("ANALYZE");
             //Look for operations with
             //  Same units
             //  Same dates
@@ -668,17 +663,18 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged)
             //  Different accounts
             //  Oposite amounts
             SKGStringListList listTmp;
-            //+A.i_group_id=0 AND +B.i_group_id=0 is for avoiding to use bad index
-            err = m_document->executeSelectSqliteOrder(
-                      "SELECT A.id, B.id FROM v_operation_tmp1 A, v_operation_tmp1 B WHERE +A.d_date=B.d_date AND A.rc_unit_id=B.rc_unit_id AND A.id<=B.id AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_QUANTITY+B.f_QUANTITY)<" % SKGServices::doubleToString(EPSILON) % " AND A.i_group_id=0 AND B.i_group_id=0 AND A.f_QUANTITY!=0",
-                      listTmp);
+            if (!err) err = m_document->executeSelectSqliteOrder(
+                                    "SELECT A.id, B.id FROM v_operation_tmp1 A, v_operation_tmp1 B WHERE +A.d_date=B.d_date AND A.rc_unit_id=B.rc_unit_id AND A.id<=B.id AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_QUANTITY+B.f_QUANTITY)<" % SKGServices::doubleToString(EPSILON) % " AND A.i_group_id=0 AND B.i_group_id=0 AND A.f_QUANTITY!=0" %
+                                    (iOnCurrentlyImport ? " AND A.t_imported='T' AND B.t_imported='T'" : ""),
+                                    listTmp);
             //Step 1 done
             if (!err) err = m_document->stepForward(1);
 
             SKGStringListList listTmp2;
             //+A.i_group_id=0 AND +B.i_group_id=0 is for avoiding to use bad index
             if (!err) err = m_document->executeSelectSqliteOrder(
-                                    "SELECT A.id, B.id FROM v_operation A, v_operation_tmp1 B, parameters P WHERE +P.t_uuid_parent=B.id||'-operation' AND A.rc_unit_id!=B.rc_unit_id AND P.t_name='SKG_OP_ORIGINAL_AMOUNT' AND A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_CURRENTAMOUNT+CAST(P.t_value AS REAL))<" % SKGServices::doubleToString(EPSILON) % " AND +A.i_group_id=0 AND +B.i_group_id=0 AND A.f_CURRENTAMOUNT!=0",
+                                    "SELECT A.id, B.id FROM v_operation A, v_operation_tmp1 B, parameters P WHERE +P.t_uuid_parent=B.id||'-operation' AND A.rc_unit_id!=B.rc_unit_id AND P.t_name='SKG_OP_ORIGINAL_AMOUNT' AND A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_CURRENTAMOUNT+CAST(P.t_value AS REAL))<" % SKGServices::doubleToString(EPSILON) % " AND +A.i_group_id=0 AND +B.i_group_id=0 AND A.f_CURRENTAMOUNT!=0" %
+                                    (iOnCurrentlyImport ? " AND A.t_imported='T' AND B.t_imported='T'" : ""),
                                     listTmp2);
 
             //Step 2 done
