@@ -102,9 +102,7 @@ public:
      * Return the mime type filter
      * @return the mime type filter. Example: "*.csv|CSV file"
      */
-    virtual inline QString getMimeTypeFilter() const {
-        return "";
-    }
+    virtual QString getMimeTypeFilter() const = 0;
 
 private:
     Q_DISABLE_COPY(SKGImportPlugin)
