@@ -138,7 +138,7 @@ SKGError SKGOperationObject::getParentAccount(SKGAccountObject& oAccount) const
     return err;
 }
 
-SKGError SKGOperationObject::setParentAccount(const SKGAccountObject& iAccount)
+SKGError SKGOperationObject::setParentAccount(const SKGAccountObject& iAccount, bool iForce)
 {
     SKGError err;
     QString currentAccount = getAttribute("rd_account_id");
@@ -146,7 +146,7 @@ SKGError SKGOperationObject::setParentAccount(const SKGAccountObject& iAccount)
     if (newAccount == "0") err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::setParentAccount")));
     else {
         if (newAccount != currentAccount) {
-            if (iAccount.isClosed()) err = SKGError(ERR_FAIL, i18nc("Error message",  "Impossible to add an operation in a closed account"));
+            if (iAccount.isClosed() && !iForce) err = SKGError(ERR_FAIL, i18nc("Error message",  "Impossible to add an operation in a closed account"));
             else err = setAttribute("rd_account_id", newAccount);
         }
     }
