@@ -350,6 +350,9 @@ QVariantList SKGReportBank::getBankTable()
                         double v2 = account.getAmount(date2);
                         double v3 = account.getAmount(date3);
                         QString type = account.getAttribute("t_BANK");
+                        //320114 vvvv
+                        if (type.isEmpty()) type = i18nc("Noun", "Unknown");
+                        //320114 ^^^^
                         QString icon = account.getAttribute("t_ICON");
                         if (!icon.isEmpty()) {
                             QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
