@@ -132,7 +132,7 @@ SKGError SKGSubOperationObject::getTracker(SKGTrackerObject& oTracker) const
     QString idS = getAttribute("r_refund_id");
     if (idS.isEmpty()) idS = '0';
     SKGError err;
-    if (getDocument()) err = getDocument()->getObject("v_refund", "id=" % idS, oTracker);
+    if (getDocument() && idS != "0") err = getDocument()->getObject("v_refund", "id=" % idS, oTracker);
     return err;
 
 }
