@@ -661,10 +661,8 @@ SKGError SKGUnitObject::addSource(const QString& iNewSource, bool iOpenSource)
     //Check if file already existing
     if (!QFile(newfile).exists()) {
         //Creation of the template
-        if (!file.open()) {
-            err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Save file '%1' failed", newfile));
-        } else {
+        if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", newfile));
+        else {
             QTextStream out(&file);
 
             out << "#" << i18nc("Description test for a text file used to define a source of download",
@@ -706,10 +704,7 @@ SKGError SKGUnitObject::deleteSource(const QString& iSource)
 
     //Delete the file
     QFile file(fileName);
-    if (!file.remove()) {
-        err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Deletion of '%1' failed", fileName));
-    }
+    if (!file.remove()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Deletion of '%1' failed", fileName));
     return err;
 }
 
@@ -813,7 +808,8 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                         //Read line
                         QString line = lines.at(i);
                         QStringList fields = SKGServices::splitCSVLine(line, ',');
-                        if (fields.count() == 7) {
+                        if (fields.count() != 7) err.setReturnCode(ERR_ABORT).setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
+                        else {
                             QDate ds = QDate::fromString(fields[0], "yyyy-MM-dd");
                             double val = SKGServices::stringToDouble(fields[6]);
 
@@ -823,9 +819,6 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                             if (!err) err = value.setDate(ds);
                             if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
                             if (!err) err = value.save();
-                        } else {
-                            err.setReturnCode(ERR_ABORT);
-                            err.setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
                         }
                     }
                 } else {
@@ -1035,10 +1028,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                             if (!err) err = value.setDate(ds);
                             if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
                             if (!err) err = value.save();
-                        } else {
-                            err.setReturnCode(ERR_ABORT);
-                            err.setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
-                        }
+                        } else err.setReturnCode(ERR_ABORT).setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
 
                         for (int j = 2; !err && j < nb; ++j) {
                             QString val = fields[j];
