@@ -139,9 +139,10 @@ public:
      * @param iValue initial value
      * @param iUnitFrom source unit
      * @param iUnitTo target unit
+     * @param iDate the date to use to compute the units values
      * @return Value in target unit
      */
-    static double convert(double iValue, const SKGUnitObject& iUnitFrom, const SKGUnitObject& iUnitTo);
+    static double convert(double iValue, const SKGUnitObject& iUnitFrom, const SKGUnitObject& iUnitTo, const QDate& iDate = QDate::currentDate());
 
     /**
      * Operator affectation
@@ -293,10 +294,11 @@ public:
     /**
      * Create a new source
      * @param iNewSource the name of the new source
+     * @param iOpenSource to open the created source with the appropriate editor
      * @return an object managing the error
      *   @see SKGError
      */
-    static SKGError addSource(const QString& iNewSource);
+    static SKGError addSource(const QString& iNewSource, bool iOpenSource = true);
 
     /**
      * To know if a source can be modified or deleted
