@@ -48,7 +48,7 @@ public:
      * Default Constructor
      * @param parent the parent
      */
-    SKGColorButton(QWidget* parent = 0);
+    explicit SKGColorButton(QWidget* parent = 0);
 
     /**
      * Default Destructor
@@ -74,7 +74,6 @@ public:
      */
     virtual QColor color() const;
 
-
     /**
      * Set the color for the color selector
      * @param iColor the color
