@@ -22,7 +22,7 @@
 #include "skgcolorbuttondesignerplugin.h"
 #include "skgcolorbutton.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
