@@ -39,7 +39,7 @@ class SKGBASEGUI_EXPORT SKGDatePickerPopup: public QMenu
     /**
      * Mode of the picker
      */
-    Q_ENUMS(ItemFlag);
+    Q_ENUMS(ItemFlag)
 public:
     /**
      * Mode of the picker
@@ -53,7 +53,7 @@ public:
     /**
      * Flags for the picker
      */
-    Q_DECLARE_FLAGS(Items, ItemFlag);
+    Q_DECLARE_FLAGS(Items, ItemFlag)
 
     /**
      *  A constructor for the SKGDatePickerPopup.
