@@ -22,7 +22,7 @@
 #include "skglineeditdesignerplugin.h"
 #include "skglineedit.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
