@@ -81,6 +81,12 @@ struct doublePointer {
     void* p2;
 };
 
+struct historyPage {
+    SKGTabPage::SKGPageHistoryItem current;
+    QList<SKGTabPage::SKGPageHistoryItem> next;
+    QList<SKGTabPage::SKGPageHistoryItem> previous;
+};
+
 class SKGMainPanelPrivate
 {
 public:
@@ -95,6 +101,7 @@ public:
     QList<SKGInterfacePlugin*> m_pluginsList;
     QMap<QString, QAction*> m_registeredGlogalAction;
     QList<QWidget*> m_hiddenWidgets;
+    QList<historyPage> m_historyClosedPages;
 
     KMenu* m_contextMenu;
     QAction* m_actHideContextItem;
@@ -114,6 +121,7 @@ public:
     KAction* m_fullScreenAction;
     KAction* m_actLock;
     KAction* m_actUnLock;
+    KAction* m_reopenLastClosed;
     KTemporaryFile m_tipsFile;
     KSystemTrayIcon* m_kSystemTrayIcon;
     QLabel* m_kNormalMessage;
@@ -217,8 +225,9 @@ public:
     void refreshTabPosition() {
         m_tabWidget->setTabPosition((KTabWidget::TabPosition) skgbasegui_settings::main_tabs_position());
     }
-
 };
+
+
 bool SKGMainPanelPrivate::m_currentActionCanceled = false;
 SKGMainPanel* SKGMainPanelPrivate::m_mainPanel = NULL;
 
@@ -831,6 +840,12 @@ void SKGMainPanel::setupActions()
     connect(d->m_resetDefaultStateAction, SIGNAL(triggered()), this, SLOT(resetDefaultState()));
     registerGlobalAction("tab_resetdefaultstate", d->m_resetDefaultStateAction);
 
+    //
+    d->m_reopenLastClosed = new KAction(KIcon("tab-new"), i18nc("Noun, user action", "Reopen last page closed"), this);
+    d->m_reopenLastClosed->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_T);
+    connect(d->m_reopenLastClosed, SIGNAL(triggered()), this, SLOT(onReopenLastClosed()));
+    registerGlobalAction("tab_reopenlastclosed", d->m_reopenLastClosed);
+
     //
     QStringList overlay;
     overlay.push_back("bookmarks");
@@ -895,6 +910,7 @@ void SKGMainPanel::setupActions()
     //Contextual menu
     d->m_tabWidget->setContextMenuPolicy(Qt::ActionsContextMenu);
     d->m_tabWidget->insertAction(0, getGlobalAction("new_tab"));
+    d->m_tabWidget->insertAction(0, getGlobalAction("tab_reopenlastclosed"));
     d->m_tabWidget->insertAction(0, getGlobalAction("tab_close"));
     d->m_tabWidget->insertAction(0, getGlobalAction("tab_closeall"));
     d->m_tabWidget->insertAction(0, getGlobalAction("tab_closeallother"));
@@ -1074,6 +1090,27 @@ void SKGMainPanel::onNext()
     }
 }
 
+void SKGMainPanel::onReopenLastClosed()
+{
+    SKGError err;
+    SKGTRACEINRC(10, "SKGMainPanel::onNext", err);
+
+    SKGTabPage::SKGPageHistoryItem current = currentPageHistoryItem();
+
+    //Get item to refresh
+    historyPage item = d->m_historyClosedPages.takeLast();
+
+    //Open page
+    SKGTabPage* cPage = openPage(getPluginByName(item.current.plugin), -1, item.current.state, item.current.name, item.current.bookmarkID);
+    if (cPage) {
+        cPage->setBookmarkID(item.current.bookmarkID);
+        cPage->setNextPages(item.next);
+        cPage->setPreviousPages(item.previous);
+    }
+
+    refresh();
+}
+
 void SKGMainPanel::onLockDocks()
 {
     QObjectList cs = children();
@@ -1424,6 +1461,7 @@ void SKGMainPanel::refresh()
     if (d->m_switchPinState) d->m_switchPinState->setEnabled(atLeastOnePageOpened);
     if (d->m_closeAllPagesAction) d->m_closeAllPagesAction->setEnabled(atLeastOnePageOpened);
     if (d->m_closeAllOtherPagesAction) d->m_closeAllOtherPagesAction->setEnabled(d->m_tabWidget->count() > 1);
+    if (d->m_reopenLastClosed) d->m_reopenLastClosed->setEnabled(d->m_historyClosedPages.count());
 
     if (d->m_saveDefaultStateAction) d->m_saveDefaultStateAction->setEnabled(toSave && !toSave->getDefaultStateAttribute().isEmpty());
     if (d->m_resetDefaultStateAction) d->m_resetDefaultStateAction->setEnabled(toSave && !toSave->getDefaultStateAttribute().isEmpty());
@@ -1532,6 +1570,9 @@ SKGTabPage* SKGMainPanel::openPage(SKGInterfacePlugin* plugin, int index, const
 
             d->m_tabWidget->removeTab(currentIndex);
             closePage(cPage);
+
+            //Repair the history of closed page
+            d->m_historyClosedPages.removeLast();
         }
     }
 
@@ -1720,8 +1761,14 @@ void SKGMainPanel::closePage(QWidget* iWidget, bool iForce)
     } else {
         SKGTabPage* toRemove = qobject_cast< SKGTabPage* >(iWidget);
         if (toRemove == NULL)  toRemove = currentPage();
-        if (toRemove && toRemove->close(iForce))
+        if (toRemove && toRemove->close(iForce)) {
+            historyPage item;
+            item.current = currentPageHistoryItem();
+            item.next = toRemove->getNextPages();
+            item.previous = toRemove->getPreviousPages();
+            d->m_historyClosedPages.push_back(item);
             delete toRemove;
+        }
     }
 
     //Show/hide main widget
@@ -1944,11 +1991,23 @@ QLabel* SKGMainPanel::statusNormalMessage() const
 
 KMessageWidget* SKGMainPanel::displayMessage(const QString& iMessage, SKGDocument::MessageType iType)
 {
-    KMessageWidget* msg = new KMessageWidget(this);
-    msg->setText(iMessage);
-    msg->setMessageType((KMessageWidget::MessageType) iType);
-    QTimer::singleShot(iType == SKGDocument::Positive ? 5000 : iType == SKGDocument::Information ? 10000 : 20000, msg, SLOT(deleteLater()));
-    d->m_mainLayout->insertWidget(qMax(d->m_mainLayout->indexOf(d->m_mainWidget) - 1, 0), msg);
+    //Create message widget
+    KMessageWidget* msg = NULL;
+    if (!iMessage.isEmpty()) {
+        msg = new KMessageWidget(this);
+        msg->setText(iMessage);
+        msg->setMessageType((KMessageWidget::MessageType) iType);
+        QTimer::singleShot(iType == SKGDocument::Positive ? 5000 : iType == SKGDocument::Information ? 10000 : 20000, msg, SLOT(deleteLater()));
+        d->m_mainLayout->insertWidget(qMax(d->m_mainLayout->indexOf(d->m_mainWidget) - 1, 0), msg);
+    }
+
+    //Emit message
+    //  [Event/error]
+    //  [Event/neutral]
+    //  [Event/positive]
+    KNotification* notify = new KNotification(iType == SKGDocument::Error ? "error" : (iType == SKGDocument::Positive ? "positive" : "neutral") , this);
+    notify->setText(iMessage);
+    notify->sendEvent();
 
     return msg;
 }
