@@ -41,22 +41,22 @@ class SKGBASEGUI_EXPORT SKGShow : public QToolButton
     /**
      * State of the object
      */
-    Q_PROPERTY(QString state READ getState WRITE setState USER true);
+    Q_PROPERTY(QString state READ getState WRITE setState USER true)
 
     /**
      * Mode
      */
-    Q_PROPERTY(OperatorMode mode READ getMode WRITE setMode);
+    Q_PROPERTY(OperatorMode mode READ getMode WRITE setMode)
 
     /**
      * Mode
      */
-    Q_PROPERTY(bool displayTitle READ getDisplayTitle WRITE setDisplayTitle);
+    Q_PROPERTY(bool displayTitle READ getDisplayTitle WRITE setDisplayTitle)
 
     /**
      * This enumerate defines type of operator
      */
-    Q_ENUMS(OperatorMode);
+    Q_ENUMS(OperatorMode)
 
 public:
 
@@ -238,7 +238,7 @@ private Q_SLOTS:
     void trigger();
 
 private:
-    Q_DISABLE_COPY(SKGShow);
+    Q_DISABLE_COPY(SKGShow)
 
     QString getTitle() const;
     void refreshTitle();
