@@ -28,13 +28,13 @@
 #include "skgmainpanel.h"
 #include "skgtreeview.h"
 
-#include "kmessagebox.h"
+#include <kmessagebox.h>
 
 #include <QtGui/QWidget>
 #include <QWebView>
 
 #include <qmath.h>
-#include "math.h"
+#include <math.h>
 
 SKGTabPage::SKGTabPage(SKGDocument* iDocument)
     : SKGWidget(iDocument), m_pin(false)
@@ -53,15 +53,20 @@ SKGTabPage::~SKGTabPage()
 bool SKGTabPage::close(bool iForce)
 {
     SKGTRACEIN(5, "SKGTabPage::close");
+    int conf = KMessageBox::Yes;
     if (!iForce && isPin()) {
-        int conf = KMessageBox::questionYesNo(this,
-                                              i18nc("Question", "Do you really want to close this pinned page?"),
-                                              i18nc("Question", "Pinned page"),
-                                              KStandardGuiItem::yes(),
-                                              KStandardGuiItem::no());
-        if (conf == KMessageBox::No) return false;
+        QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
+        conf = KMessageBox::questionYesNo(this,
+                                          i18nc("Question", "Do you really want to close this pinned page?"),
+                                          i18nc("Question", "Pinned page"),
+                                          KStandardGuiItem::yes(),
+                                          KStandardGuiItem::no(),
+                                          "closepinnedpage"
+                                         );
+        QApplication::restoreOverrideCursor();
     }
     overwrite();
+    if (conf == KMessageBox::No) return false;
     return QWidget::close();
 }
 
