@@ -186,7 +186,7 @@ public Q_SLOTS:
     virtual bool close(bool iForce = false);
 
 private:
-    Q_DISABLE_COPY(SKGTabPage);
+    Q_DISABLE_COPY(SKGTabPage)
 
     QString       m_bookmarkID;
     QList<SKGTabPage::SKGPageHistoryItem> m_previousPages;
