@@ -1002,10 +1002,8 @@ void SKGTreeView::onExport()
     if (extension == "CSV") {
         //Write file
         KSaveFile file(fileName);
-        if (!file.open()) {
-            err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Save file '%1' failed" , fileName));
-        } else {
+        if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , fileName));
+        else {
             QTextStream out(&file);
             out.setCodec(lastCodecUsed.toAscii().constData());
             QStringList dump = SKGServices::tableToDump(getTable(), SKGServices::DUMP_CSV);
@@ -1053,10 +1051,8 @@ void SKGTreeView::onExport()
     } else {
         //Write file
         KSaveFile file(fileName);
-        if (!file.open()) {
-            err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Save file '%1' failed" , fileName));
-        } else {
+        if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , fileName));
+        else {
             QTextStream out(&file);
             out.setCodec(lastCodecUsed.toAscii().constData());
             QStringList dump = SKGServices::tableToDump(getTable(), SKGServices::DUMP_TEXT);
