@@ -22,7 +22,7 @@
 #include "skgwebviewdesignerplugin.h"
 #include "skgwebview.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
