@@ -56,12 +56,6 @@ void SKGWidget::setState(const QString& /*iState*/)
 {
 }
 
-QWidget* SKGWidget::getDragWidget()
-{
-    QWidget* w = this->findChild<QWidget*>("kGroup");
-    if (!w) w = this;
-    return w;
-}
 SKGObjectBase::SKGListSKGObjectBase SKGWidget::getSelectedObjects()
 {
     SKGObjectBase::SKGListSKGObjectBase selection;
