@@ -798,6 +798,14 @@ public Q_SLOTS:
      */
     virtual SKGReport* getReport();
 
+    /**
+     * Copy a document into an JSON document.
+     * @param oDocument the json document
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError copyToJson(QString& oDocument) const;
+
 Q_SIGNALS:
     /**
      * This signal is launched by endTransaction on all tables modified when a huge modification occures on the model
