@@ -117,14 +117,16 @@ int SKGError::getReturnCode() const
     return m_rc;
 }
 
-void SKGError::setReturnCode(int iReturnCode)
+SKGError& SKGError::setReturnCode(int iReturnCode)
 {
     m_rc = iReturnCode;
+    return *this;
 }
 
-void SKGError::setMessage(const QString& iMessage)
+SKGError& SKGError::setMessage(const QString& iMessage)
 {
     m_message = iMessage;
+    return *this;
 }
 
 QString SKGError::getMessage() const
@@ -160,18 +162,19 @@ int SKGError::getHistoricalSize() const
     return output;
 }
 
-void SKGError::addError(int iRc, const QString& iMessage)
+SKGError& SKGError::addError(int iRc, const QString& iMessage)
 {
     SKGError* pe = new SKGError(*this);
     setReturnCode(iRc);
     setMessage(iMessage);
     delete m_previousError;
     m_previousError = pe;
+    return *this;
 }
 
-void SKGError::addError(const SKGError& iError)
+SKGError& SKGError::addError(const SKGError& iError)
 {
-    addError(iError.getReturnCode(), iError.getMessage());
+    return addError(iError.getReturnCode(), iError.getMessage());
 }
 
 SKGError* SKGError::getPreviousError() const
