@@ -134,14 +134,16 @@ public slots:
     *         0 : It's not an error (SUCCEEDED)
     *         <0: It's just a warning (SUCCEEDED)
     *         >0: It's not error (FAILED)
+    * @return itself to facilitate usage
     */
-    virtual void setReturnCode(int iReturnCode);
+    virtual SKGError& setReturnCode(int iReturnCode);
 
     /**
     * Set the message associated to this error
     * @param iMessage the message
+    * @return itself to facilitate usage
     */
-    virtual void setMessage(const QString&   iMessage);
+    virtual SKGError& setMessage(const QString&   iMessage);
 
     /**
     * Return the message associated to this error
@@ -171,14 +173,16 @@ public slots:
     * Add a new historical message to the current error.
     * @param iRc the error code
     * @param iMessage the error message
+    * @return itself to facilitate usage
     */
-    virtual void addError(int iRc, const QString& iMessage);
+    virtual SKGError& addError(int iRc, const QString& iMessage);
 
     /**
     * Add a new historical message to the current error.
     * @param iError the error
+    * @return itself to facilitate usage
     */
-    virtual void addError(const SKGError& iError);
+    virtual SKGError& addError(const SKGError& iError);
 
     /**
     * Return previous error associated to this SKGError in the historical
