@@ -426,7 +426,7 @@ SKGError SKGObjectBase::remove(bool iSendMessage, bool iForce) const
         QString displayname = getDisplayName(); //Must be done before the delete order
         if (!err) err = d->document->executeSqliteOrder("DELETE FROM " % getRealTable() % " WHERE id=" % SKGServices::intToString(d->id));
         if (iSendMessage && !err && !displayname.isEmpty())
-            err = d->document->sendMessage(i18nc("An information to the user that something was deleted", "'%1' has been deleted", displayname), false);
+            err = d->document->sendMessage(i18nc("An information to the user that something was deleted", "'%1' has been deleted", displayname), SKGDocument::Hidden);
     }
 
     return err;
