@@ -81,7 +81,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    static SKGError getReportFormTemplate(SKGReport* iReport, const QString& iFile, QString& oHtml);
+    static SKGError getReportFromTemplate(SKGReport* iReport, const QString& iFile, QString& oHtml);
 
 protected:
     /**
@@ -94,7 +94,7 @@ protected:
     QHash<QString, QVariant> m_cache;
 
 private:
-    Q_DISABLE_COPY(SKGReport);
+    Q_DISABLE_COPY(SKGReport)
 };
 
 #endif // SKGREPORT_H
