@@ -622,10 +622,8 @@ SKGError SKGServices::downloadToStream(const KUrl& iSourceUrl, QByteArray& oStre
     if (!err) {
         //Open file
         QFile file(tmpFile);
-        if (!file.open(QIODevice::ReadOnly)) {
-            err.setReturnCode(ERR_FAIL);
-            err.setMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
-        } else {
+        if (!file.open(QIODevice::ReadOnly)) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
+        else {
             oStream = file.readAll();
 
             //close file
@@ -656,10 +654,7 @@ SKGError SKGServices::upload(const KUrl& iSourceUrl, const KUrl& iDescUrl)
     if (iDescUrl != iSourceUrl) {
         KIO::Job* getJob = KIO::file_copy(iSourceUrl, iDescUrl, -1, KIO::Overwrite | KIO::HideProgressInfo);
         //getJob->ui()->setWindow(window);
-        if (!KIO::NetAccess::synchronousRun(getJob, 0)) {
-            err.setReturnCode(ERR_ABORT);
-            err.setMessage(getJob->errorString());
-        }
+        if (!KIO::NetAccess::synchronousRun(getJob, 0)) err.setReturnCode(ERR_ABORT).setMessage(getJob->errorString());
     }
     return err;
 }
@@ -769,7 +764,7 @@ SKGError SKGServices::copySqliteDatabaseToXml(QSqlDatabase* iDb, QDomDocument& o
         int nb = listTables.count();
         for (int i = 0; !err && i < nb; ++i) {
             QString tableName = listTables.at(i);
-            if (!tableName.startsWith(QLatin1String("sqlite_"))) {
+            if (!tableName.startsWith(QLatin1String("sqlite_")) && !tableName.startsWith(QLatin1String("vm_"))) {
                 QDomElement table = oDocument.createElement("table");
                 document.appendChild(table);
                 table.setAttribute("name", tableName);
@@ -797,56 +792,6 @@ SKGError SKGServices::copySqliteDatabaseToXml(QSqlDatabase* iDb, QDomDocument& o
     return err;
 }
 
-SKGError SKGServices::copySqliteDatabaseToJson(QSqlDatabase* iDb, QString& oDocument)
-{
-    SKGError err;
-    SKGTRACEINRC(10, "SKGServices::copySqliteDatabaseToXml", err);
-    if (iDb) {
-        oDocument = "{\n";
-
-        // Copy the tables
-        QStringList listTables = iDb->tables();
-        int nb = listTables.count();
-        for (int i = 0; !err && i < nb; ++i) {
-            QString tableName = listTables.at(i);
-            if (!tableName.startsWith(QLatin1String("sqlite_"))) {
-                oDocument += "\"" % tableName % "\":\n[\n";
-
-                SKGStringListList listRows;
-                err = SKGServices::executeSelectSqliteOrder(iDb, "SELECT * FROM " % tableName, listRows);
-                int nbRows = listRows.count();
-                if (nbRows) {
-                    QStringList titles = listRows.at(0);
-                    for (int j = 1; !err && j < nbRows; ++j) { //Forget title
-                        QStringList values = listRows.at(j);
-
-                        oDocument += '{';
-                        int nbVals = values.count();
-                        for (int k = 0; k < nbVals; ++k) {
-                            QString v = values.at(k);
-                            v = v.replace("\\", "\\\\");
-                            v = v.replace('\t', "\\\t");
-                            v = v.replace('\r', "\\\r");
-                            v = v.replace('\n', "\\\n");
-                            v = v.replace('\f', "\\\f");
-                            v = v.replace('\b', "\\\b");
-                            v = v.replace('/', "\\/");
-                            v = v.replace('"', "\\\"");
-                            oDocument += '"' % titles.at(k) % "\":\"" % v % '"';
-                            if (k < nbVals - 1) oDocument += ',';
-                        }
-                        oDocument += '}';
-                        if (j < nbRows - 1) oDocument += ',';
-                        oDocument += '\n';
-                    }
-                }
-                oDocument += "]\n";
-            }
-        }
-    }
-    return err;
-}
-
 SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iMemoryDb, bool iFromFileToMemory)
 {
     SKGError err;
@@ -960,11 +905,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
         }
 
         //Check if created file exists
-        if (!err && !iFromFileToMemory && !QFile(dbFileName).exists()) {
-            //Set error message
-            err.setReturnCode(ERR_FAIL);
-            err.setMessage(i18nc("An error message: creating a file failed", "Creation file '%1' failed", dbFileName));
-        }
+        if (!err && !iFromFileToMemory && !QFile(dbFileName).exists()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message: creating a file failed", "Creation file '%1' failed", dbFileName));
     }
     if (err) err.addError(SQLLITEERROR + ERR_FAIL, i18nc("Error message: something failed", "%1 failed", QString("SKGServices::copySqliteDatabase()")));
     return err;
@@ -1337,5 +1278,4 @@ QString SKGServices::encodeForUrl(const QString& iString)
     return KUrl::toPercentEncoding(iString);
 }
 
-
 #include "skgservices.moc"
