@@ -349,15 +349,6 @@ public:
      */
     static SKGError copySqliteDatabaseToXml(QSqlDatabase* iDb, QDomDocument& oDocument);
 
-    /**
-     * Copy a sqlite database into an JSON document.
-     * @param iDb the sqlite pointer corresponding to database
-     * @param oDocument the json document
-     * @return An object managing the error
-     *   @see SKGError
-     */
-    static SKGError copySqliteDatabaseToJson(QSqlDatabase* iDb, QString& oDocument);
-
     /**
      * Execute a sqlite orders
      * @param iDb a database pointer
