@@ -117,7 +117,7 @@ public:
     * @param iRC A pointer of the error object of the calling methode
     *   The SKGError
     */
-    SKGTraces(int iLevel, const QString& iName, SKGError* iRC = NULL);
+    explicit SKGTraces(int iLevel, const QString& iName, SKGError* iRC = NULL);
 
     /**
     * Destructor
