@@ -124,7 +124,7 @@ public:
     virtual ~SKGTransactionMng();
 
 private:
-    Q_DISABLE_COPY(SKGTransactionMng);
+    Q_DISABLE_COPY(SKGTransactionMng)
 
     SKGError* m_error;
     SKGDocument* m_parentDocument;
