@@ -27,8 +27,10 @@
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <KDE/KLocale>
-#include <QCoreApplication>
+#include <kurl.h>
 
+#include <QCoreApplication>
+#include <QFileInfo>
 
 /**
  * To compute the version
@@ -94,12 +96,16 @@ int main(int argc, char** argv)
 
     //Initialisation of a bank document
     SKGDocumentBank document;
+    document.setComputeBalances(false);
     if (!err) err = document.initialize();
     if (!err) {
         //Import
-        SKGBEGINTRANSACTION(document, "IMPORT", err);
-        SKGImportExportManager imp(&document, args->getOption("in"));
+        QString file = args->getOption("in");
+        QFileInfo fi(file);
+        if (fi.exists()) file = fi.absoluteFilePath();
+        SKGImportExportManager imp(&document, KUrl::fromLocalFile(file));
         QMap<QString, QString>  parameters = imp.getImportParameters();
+        parameters["import_by_load"] = 'Y';
         QStringList params = args->getOptionList("param");
         QStringList values = args->getOptionList("value");
         int nb = qMin(params.count(), values.count());
@@ -116,20 +122,39 @@ int main(int argc, char** argv)
             SKGTRACE << i.key() << "=" << i.value() << endl;
         }
         SKGTRACESEPARATOR;
-        SKGTRACE << i18nc("Title of a console trace section", " Imported file:") << imp.getFileName()  << endl;
-        if (!err) err = imp.importFile();
+        SKGTRACE << i18nc("Title of a console trace section", " Imported file:") << imp.getFileName().prettyUrl()  << endl;
+        if (fi.suffix().toUpper() == "SKG") {
+            err = document.load(file, parameters["password"]);
+        } else {
+            SKGBEGINTRANSACTION(document, "IMPORT", err);
+            if (!err) err = imp.importFile();
+        }
     }
     if (!err) {
         //Export
-        SKGImportExportManager exp(&document, args->getOption("out"));
+        QString file = args->getOption("out");
+        QFileInfo fi(file);
+        if (fi.exists()) file = fi.absoluteFilePath();
+        SKGImportExportManager exp(&document, KUrl::fromLocalFile(args->getOption("out")));
         SKGTRACESEPARATOR;
-        SKGTRACE << i18nc("Title of a console trace section", " Exported file:") << exp.getFileName()  << endl;
-        err = exp.exportFile();
+        SKGTRACE << i18nc("Title of a console trace section", " Exported file:") << exp.getFileName().prettyUrl()  << endl;
+        if (fi.suffix().toUpper() == "SKG") {
+            err = document.saveAs(file, true);
+        } else {
+            err = exp.exportFile();
+        }
     }
     args->clear(); // Free up some memory.
 
     if (err) {
         SKGTRACESUITE << err.getFullMessageWithHistorical() << endl;
+        SKGTRACESEPARATOR;
+        SKGTRACE << i18nc("Title of a console trace section", " FAILED") << endl;
+        SKGTRACESEPARATOR;
+    } else {
+        SKGTRACESEPARATOR;
+        SKGTRACE << i18nc("Title of a console trace section", " SUCCESSFUL") << endl;
+        SKGTRACESEPARATOR;
     }
 
     SKGTraces::dumpProfilingStatistics();
